<?php
/**
* Email Design Studio plugin file. 
*
* Copyright (C) 2010-2020, Smackcoders Inc - info@smackcoders.com 
*/

namespace Smackcoders\SMEMAILCUSTOM;

if ( ! defined( 'ABSPATH' ) ) {
	die;
}

//A singleton class
class Admin
{
    protected static $instance = null;
    private static $sections = null;
    private static $sections_added  = array();
    private static $panels_added = array();
    private static $panels = null;
    private static $settings = null;
    private static $woo_settings = null;
  
    public static function getInstance() {
		if ( null == self::$instance ) {
			self::$instance = new self;
            self::$instance->doHooks();
		}
		return self::$instance;
	}

    public function doHooks(){
        
        add_action('admin_enqueue_scripts',array(self::$instance, 'sm_enqueue_function'));
        // Add settings.
		add_action( 'customize_register', array( self::$instance, 'add_settings' ) );

        // Add controls, sections and panels.
		add_action( 'customize_register', array( self::$instance, 'add_controls' ) );

        // Remove unrelated components.
		add_filter( 'customize_loaded_components', array( self::$instance, 'remove_unrelated_components' ), 99, 2 );

        // Remove unrelated sections.
		add_filter( 'customize_section_active', array( self::$instance, 'remove_unrelated_sections' ), 99, 2 );

        // Remove unrelated controls.
		//add_filter( 'customize_control_active', array( self::$instance, 'remove_unrelated_controls' ), 99, 2 );

        // Unhook divi front end.
        add_action( 'woomail_footer', array( self::$instance, 'sm_unhook_divi' ), 10 );

        // Unhook LifterLMS front end.
        add_action( 'woomail_footer', array( self::$instance, 'sm_unhook_lifter' ), 10 );

        add_action( 'customize_preview_init', array( self::$instance, 'sm_customizer_live_preview' ), 50 );

        $order_table_obj = new SMFetchTemplate();
        add_action( 'customize_save', array( $order_table_obj, 'sm_customizer_save' ), 10, 1 );
    
        //send preview test mail ajax
        add_action(	'wp_ajax_smmail_test_email' , array( self::$instance, 'smmail_test_email'));
        add_action('wp_ajax_smmail_container_width', array(self::$instance,'smmail_container_width'));
        add_action(	'wp_ajax_smmail_selected_theme' , array( self::$instance, 'smmail_selected_theme'));
        add_action(	'wp_ajax_smmail_selected_order_type' , array( self::$instance, 'smmail_selected_order_type'));
        add_action('wp_ajax_smmail_log_type',array(self::$instance,'smmail_log_type'));
        add_action( 'init',array( self::$instance,'register_awaiting_shipment_order_status'));  
        add_filter( 'wc_order_statuses',array( self::$instance,'add_awaiting_shipment_to_order_statuses'));
        add_action('wp_ajax_sm_reset_option',array(self::$instance,'sm_reset_option'));
    }

    public function register_awaiting_shipment_order_status() {
        register_post_status( 'wc-product-delivered', array(
            'label'                     => 'Product Delivered',
            'public'                    => true,
            'exclude_from_search'       => false,
            'show_in_admin_all_list'    => true,
            'show_in_admin_status_list' => true,
            'label_count'               => _n_noop( 'Product Delivered (%s)', 'Product Delivered (%s)' )
        ) );
    }

    public function add_awaiting_shipment_to_order_statuses( $order_statuses ) {
        $new_order_statuses = array();
     
        // add new order status after processing
        foreach ( $order_statuses as $key => $status ) {
            $new_order_statuses[ $key ] = $status;
     
            if ( 'wc-processing' === $key ) {
                $new_order_statuses['wc-product-delivered'] = 'Product Delivered';
            }
        }
        return $new_order_statuses;
    }
    public function sm_reset_option(){
        global $wpdb;
        $get_url = wp_unslash( $_SERVER['HTTP_REFERER'] ); 
        $url_components = parse_url($get_url); 
        parse_str($url_components['query'], $params); 
        $templateid = $params['templateid'];
	    $themeid = $params['themeid'];
        $get_permanent_name = sanitize_text_field($_POST['name']);
        $value = self::$instance->get_permanent_value($get_permanent_name);
        $permanent_value['headerlogowidth'] = $value;
        echo json_encode($permanent_value);
        wp_die();
    }
    public function get_permanent_value($type){
        global $wpdb;
        $get_url = wp_unslash( $_SERVER['HTTP_REFERER'] );
        $url_components = parse_url($get_url); 
        parse_str($url_components['query'], $params); 
       
        if(isset($params['templateid'])){
            $templateid = $params['templateid'];
            $themeid = $params['themeid'];
        }
        else{
            $templateid = 1;
            $themeid = 1;
        }

        $get_template_details = $wpdb->get_var("SELECT template_details FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = $templateid AND theme_id = $themeid AND status = 'permanent'");
		$unser_template_details = json_decode($get_template_details, true);
	
        $template_details_array = array(
            'header_position' => array('parent' => 'header_details', 'child' => 'image_position'),
            'header_image_upload' => array('parent' => 'header_details', 'child' => 'image_url'),
            'header_bgcolor' => array('parent' => 'header_details', 'child' => 'bg_color'),
            'header_logo_width' => array('parent' => 'header_details', 'child' => 'width'),
            'header_logo_height' => array('parent' => 'header_details', 'child' => 'height'),
            'header_wsize' => array('parent' => 'header_details', 'child' => 'rwidth'),
            //'header_height' => array('parent' => 'header_details', 'child' => 'hrheight'),

            'text_fontcolor1' => array('parent' => "maindragtext_{$templateid}{$themeid}1", 'child' => 'ftcolor'),
            'text_fontcolor2' => array('parent' => "maindragtext_{$templateid}{$themeid}2", 'child' => 'ftcolor'),
            'text_fontsize1' => array('parent' => "maindragtext_{$templateid}{$themeid}1", 'child' => 'ftsize'),
            'text_fontsize2' => array('parent' => "maindragtext_{$templateid}{$themeid}2", 'child' => 'ftsize'),
            'text_fontstyle1' => array('parent' => "maindragtext_{$templateid}{$themeid}1", 'child' => 'ftstyle'),
            'text_fontstyle2' => array('parent' => "maindragtext_{$templateid}{$themeid}2", 'child' => 'ftstyle'),
            'text_bgcolor1' => array('parent' => "maindragtext_{$templateid}{$themeid}1", 'child' => 'bgcolor'),
            'text_bgimage1' => array('parent' => "maindragtext_{$templateid}{$themeid}1", 'child' => 'bgimage'),
            'text_bgcolor2' => array('parent' => "maindragtext_{$templateid}{$themeid}2", 'child' => 'bgcolor'),
            'text_bgimage2' => array('parent' => "maindragtext_{$templateid}{$themeid}2", 'child' => 'bgimage'),
            'text_wsize1' => array('parent' => "maindragtext_{$templateid}{$themeid}1", 'child' => 'rwidth'),
            'text_wsize2' => array('parent' => "maindragtext_{$templateid}{$themeid}2", 'child' => 'rwidth'),
            'text_top1' => array('parent' => "maindragtext_{$templateid}{$themeid}1", 'child' => 'top'),
            'text_top2' => array('parent' => "maindragtext_{$templateid}{$themeid}2", 'child' => 'top'),
            'text_bottom1' => array('parent' => "maindragtext_{$templateid}{$themeid}1", 'child' => 'bottom'),
            'text_bottom2' => array('parent' => "maindragtext_{$templateid}{$themeid}2", 'child' => 'bottom'),
            //'text_height1' => array('parent' => "maindragtext_{$templateid}{$themeid}1", 'child' => 'height'),
            //'text_height2' => array('parent' => "maindragtext_{$templateid}{$themeid}2", 'child' => 'height'),
           
            'image_position' => array('parent' => 'imageblockdrag', 'child' => 'img_position'),
            'image_upload' => array('parent' => 'imageblockdrag', 'child' => 'img_url'),
            'image_bgcolor' => array('parent' => 'imageblockdrag', 'child' => 'img_bgcolor'),
            'image_width' => array('parent' => 'imageblockdrag', 'child' => 'img_width'),
            'image_height' => array('parent' => 'imageblockdrag', 'child' => 'img_height'),
            'image_wsize' => array('parent' => 'imageblockdrag', 'child' => 'rwidth'),
            'image_top' => array('parent' => 'imageblockdrag', 'child' => 'top'),
            'image_bottom' => array('parent' => 'imageblockdrag', 'child' => 'bottom'),
            'image_rounded' => array('parent' => 'imageblockdrag','child' => 'rounded'),
            'image_border' => array('parent' => 'imageblockdrag','child' => 'border'),
            'image_bcolor' => array('parent' => 'imageblockdrag','child' => 'bcolor'),
            'image_bsize' => array('parent' => 'imageblockdrag','child' => 'bsize'),
            //'sm_image_height' => array('parent' => 'imageblockdrag', 'child' => 'height'),

            'button_link' => array('parent' => 'button_details', 'child' => 'link'),
            'button_text' => array('parent' => 'button_details', 'child' => 'text'),
            'button_color' => array('parent' => 'button_details', 'child' => 'color'),
            'button_position' => array('parent' => 'button_details', 'child' => 'position'),
            'button_bgcolor' => array('parent' => 'button_details', 'child' => 'bg_color'),
            'button_wsize' => array('parent' => 'button_details', 'child' => 'rwidth'),
            'button_height' => array('parent' => 'button_details', 'child' => 'bheight'),
            'button_radius' => array('parent' => 'button_details', 'child' => 'bradius'),
            //'sm_button_height' => array('parent' => 'button_details', 'child' => 'height'),
            'button_widthsize' => array('parent' => 'button_details', 'child' => 'bwidth'),
            'button_ftcolor' => array('parent' => 'button_details', 'child' => 'bftcolor'),

            'divider_width1' => array('parent' => "hr_details_{$templateid}{$themeid}1", 'child' => 'width'),
            'divider_width2' => array('parent' => "hr_details_{$templateid}{$themeid}2", 'child' => 'width'),
            'divider_height1' => array('parent' => "hr_details_{$templateid}{$themeid}1", 'child' => 'height'),
            'divider_height2' => array('parent' => "hr_details_{$templateid}{$themeid}2", 'child' => 'height'),
            'divider_color1' => array('parent' => "hr_details_{$templateid}{$themeid}1", 'child' => 'color'),
            'divider_color2' => array('parent' => "hr_details_{$templateid}{$themeid}2", 'child' => 'color'),
            'divider_bgcolor1' => array('parent' => "hr_details_{$templateid}{$themeid}1", 'child' => 'bgcolor'),
            'divider_bgcolor2' => array('parent' => "hr_details_{$templateid}{$themeid}2", 'child' => 'bgcolor'),
            'divider_wsize1' => array('parent' => "hr_details_{$templateid}{$themeid}1", 'child' => 'rwidth'),
            'divider_wsize2' => array('parent' => "hr_details_{$templateid}{$themeid}2", 'child' => 'rwidth'),
            //'sm_divider_height' => array('parent' => 'hr_details', 'child' => 'dvheight'),

            'textarea_entertext' => array('parent' => 'maintext_details', 'child' => 'text'),
            'textarea_position' => array('parent' => 'maintext_details', 'child' => 'position'),
            'textarea_fontcolor' => array('parent' => 'maintext_details', 'child' => 'color'),
            'textarea_style' => array('parent' => 'maintext_details', 'child' => 'style'),
            'textarea_size' => array('parent' => 'maintext_details', 'child' => 'size'),
            'textarea_bgcolor' => array('parent' => 'maintext_details', 'child' => 'bgcolor'),
            'textarea_wsize' => array('parent' => 'maintext_details', 'child' => 'rwidth'),
            //'textarea_height' => array('parent' => 'maintext_details', 'child' => 'height'),

            'social_position' => array('parent' => 'socialblockdrag', 'child' => 'position'),
            'social_bgcolor' => array('parent' => 'socialblockdrag', 'child' => 'bgcolor'),
            'social_fblink' => array('parent' => 'socialblockdrag', 'child' => 'fb'),
            'social_twlink' => array('parent' => 'socialblockdrag', 'child' => 'twitter'),
            'social_glink' => array('parent' => 'socialblockdrag', 'child' => 'google'),
            'social_ldlink' => array('parent' => 'socialblockdrag', 'child' => 'linkedin'),
            'social_sklink' => array('parent' => 'socialblockdrag', 'child' => 'skype'),
            'social_ytlink' => array('parent' => 'socialblockdrag', 'child' => 'youtube'),
            'social_inlink' => array('parent' => 'socialblockdrag', 'child' => 'instagram'),
            'social_wsize' => array('parent' => 'socialblockdrag', 'child' => 'rwidth'),
            //'social_height' => array('parent' => 'socialblockdrag', 'child' => 'height'),

            'order_fontstyle' => array('parent' => 'order_details', 'child' => 'ftfamily'),
            'order_tr_bgcolor' => array('parent' => 'order_details', 'child' => 'trbgcolor'),
            'order_fontcolor' => array('parent' => 'order_details', 'child' => 'ftcolor'),
            'order_hr_color' => array('parent' => 'order_details', 'child' => 'hrcolor'),
            'order_bgcolor' => array('parent' => 'order_details', 'child' => 'orbgcolor'),
            'order_wsize' => array('parent' => 'order_details', 'child' => 'rwidth'),
            //'order_height' => array('parent' => 'order_details', 'child' => 'height'),

            'customer_fontfamily' => array('parent' => 'customer_details', 'child' => 'style'),
            'customer_bgcolor' => array('parent' => 'customer_details', 'child' => 'bgcolor'),
            'customer_ftcolor' => array('parent' => 'customer_details', 'child' => 'ftcolor'),
            'customer_wsize' => array('parent' => 'customer_details', 'child' => 'rwidth'),
            //'customer_height' => array('parent' => 'customer_details', 'child' => 'height'),

        );
      
        if($type == 'background_bgcolor'){
            $get_bgcolor = $wpdb->get_var("SELECT background_color FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = $templateid AND theme_id = $themeid AND status = 'permanent'");
            return $get_bgcolor;
        }
        elseif($type == 'mail_subject'){
            $get_subject = $wpdb->get_var("SELECT subject FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = $templateid AND theme_id = $themeid AND status = 'permanent'");
            return $get_subject;
        }
        elseif(strpos($type, 'sm_border_') !== FALSE){
            $get_border_details = $wpdb->get_var("SELECT container_details FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = $templateid AND theme_id = $themeid AND status = 'permanent'");
            $unser_border_details = json_decode($get_border_details, true);
        
            $border_fields_array = array(
                'sm_border_twidth' => 'border_twidth',
                'sm_border_rwidth' => 'border_rwidth',
                'sm_border_bwidth' => 'border_bwidth',
                'sm_border_lwidth' => 'border_lwidth',
                'sm_border_color'  => 'border_color',
                'sm_border_radius' => 'border_radius',
                'sm_border_bgcolor'=> 'border_bgcolor',
                'sm_border_bgimage'=> 'border_bgimage',
                'sm_border_container_width' => 'container_width',
                //'sm_border_container_height' => 'container_height',
                //'sm_border_container_bgcolor' => 'container_bgcolor'
            );
            return $unser_border_details[$border_fields_array[$type]];
        }
        else{
            if(isset($unser_template_details[$template_details_array[$type]['parent']])){
                $unser_template_details[$template_details_array[$type]['parent']][$template_details_array[$type]['child']] = isset($unser_template_details[$template_details_array[$type]['parent']][$template_details_array[$type]['child']])?$unser_template_details[$template_details_array[$type]['parent']][$template_details_array[$type]['child']]:'';
                return $unser_template_details[$template_details_array[$type]['parent']][$template_details_array[$type]['child']];
            }   
        }
    }
   public function smmail_log_type(){
    $email_details = intval($_POST['order_type']);
    update_option('sm_mail_log_details', $email_details);  
    echo json_encode($email_details);
    wp_die();
   }
    public function smmail_selected_theme(){
        $get_theme_id = intval($_POST['selected_theme']);
        update_option('sm_mail_selected_theme', $get_theme_id);
        $get_last_edited_template = get_option('sm_mail_last_edited_template');

        $get_order_type = get_option("sm_mail_selected_template".$get_theme_id);
        global $wpdb;
        if($gat_order_type ="new_account"){
          $templateid = $wpdb->get_var("SELECT template_id FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_type ='New Account' AND status = 'temporary' ");
          $template_id['templateid'] = $templateid;
        }
        if($get_order_type == "reset_password"){
            $templateid = $wpdb->get_var("SELECT template_id FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_type ='Reset Password' AND status = 'temporary'");
            $template_id['templateid'] = $templateid;
        }
        if($get_order_type == "blog_comment"){
            $templateid = $wpdb->get_var("SELECT template_id FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_type ='Blog Comment' AND status = 'temporary'");
            $template_id['templateid'] = $templateid;
        }
        if($get_order_type == "product_delivered"){
            $templateid = $wpdb->get_var("SELECT template_id FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_type ='Product Delivered' AND status = 'temporary'");
            $template_id['templateid'] = $templateid;
        }
        if($get_order_type == "new_order"){
            $templateid = $wpdb->get_var("SELECT template_id FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_type ='New Order'AND status = 'temporary'");
            $template_id['templateid'] = $templateid;
        }
        if($get_order_type == "completed_order"){
            $templateid = $wpdb->get_var("SELECT template_id FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_type ='Completed Order' AND status = 'temporary'");
            $template_id['templateid'] = $templateid;
        }
        if($get_order_type == "processing_order"){
            $templateid = $wpdb->get_var("SELECT template_id FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_type ='Processing Order' AND status = 'temporary'");
            $template_id['templateid'] = $templateid;
        }
        if($get_order_type == "onhold_order"){
            $templateid = $wpdb->get_var("SELECT template_id FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_type ='On Hold Order' AND status = 'temporary'");
            $template_id['templateid'] = $templateid;
        }
        if($get_order_type == "failed_order"){
            $templateid = $wpdb->get_var("SELECT template_id FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_type ='Failed Order' AND status = 'temporary'");
            $template_id['templateid'] = $templateid;
        }
        if($get_order_type == "cancelled_order"){
            $templateid = $wpdb->get_var("SELECT template_id FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_type ='Cancelled Order' AND status = 'temporary'");
            $template_id['templateid'] = $templateid;
        }
        if($get_order_type == "refunded_order"){
            $templateid = $wpdb->get_var("SELECT template_id FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_type ='Refunded Order' AND status = 'temporary'");
            $template_id['templateid'] = $templateid;
        }
        if($get_order_type == "customer_invoice"){
            $templateid = $wpdb->get_var("SELECT template_id FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_type ='Customer Invoice' AND status = 'temporary'");
            $template_id['templateid'] = $templateid;
        }
        if($get_order_type == "note_to_customer"){
            $templateid = $wpdb->get_var("SELECT template_id FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_type ='Note To Customer' AND status = 'temporary'");
            $template_id['templateid']=$templateid;
        }
        if($get_order_type == "contact_form_confirmation_mail"){
            $templateid = $wpdb->get_var("SELECT template_id FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_type ='Confirmation Mail' AND status = 'temporary'");
            $template_id['templateid']=$templateid;
        }
        if($get_order_type == "wpforms_confirmation_mail"){
            $templateid = $wpdb->get_var("SELECT template_id FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_type ='WP Forms Confirmation Mail' AND status = 'temporary'");
            $template_id['templateid']=$templateid;
        }
        update_option("sm_mail_{$get_order_type}_activate_template", $get_theme_id);
        echo json_encode($template_id);
        
        wp_die();
    }

    public function smmail_selected_order_type(){
        $get_order_type = sanitize_text_field($_POST['order_type']);
        $get_last_selected_theme = get_option('sm_mail_selected_theme');

        $mail_order_types_id = array(
            'new_account' => 1,
            'reset_password' => 2,
            'blog_comment' => 3,
            'product_delivered' => 4,
            'new_order' => 5,
            'completed_order' => 6,
            'processing_order' => 7,
            'onhold_order' => 8,
            'failed_order' => 9,
            'cancelled_order' => 10,
            'refunded_order' => 11,
            'customer_invoice' => 12,
            'note_to_customer' => 13,
            'contact_form_confirmation_mail' => 14,
            'wpforms_confirmation_mail' => 15,
        );
        
        if($get_order_type != 'none'){
            $result['themeid'] = $get_last_selected_theme;
            $result['templateid'] = $mail_order_types_id[$get_order_type];
            update_option("sm_mail_{$get_order_type}_activate_template", $get_last_selected_theme);

            update_option("sm_mail_selected_template".$get_last_selected_theme, $get_order_type);

            echo json_encode($result);
            wp_die();
        }
    }

    public function smmail_test_email(){
      
        global $wpdb;
        $get_recipient_mail = get_option('sm_mail_customiser_recipient_email');

        $get_url = wp_unslash( $_SERVER['HTTP_REFERER']);
        $url_components = parse_url($get_url); 
        parse_str($url_components['query'], $params); 

        $templateid = $params['templateid'];
        $themeid = $params['themeid'];

        $get_template_details = $wpdb->get_var("SELECT template_details FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = $templateid AND theme_id = $themeid AND status = 'temporary'");

        $unser_template_details = json_decode($get_template_details, true);	
        $template_obj = new SMTemplatePage();

        $value = '';
        foreach($unser_template_details as $template_key => $template_value){
            $value .= $template_obj->drag_template_details($template_key, 'edit', 'template_details', $templateid, $themeid);
        }

        $get_template_bgcolor = '#FFFFFF';
	
        $get_template_border_details = $wpdb->get_var("SELECT container_details FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = $templateid AND theme_id = $themeid AND status = 'temporary'");
        $unser_template_border_details = json_decode($get_template_border_details, true);	
    
        $border_rwidth = $unser_template_border_details['border_rwidth'];
        $border_lwidth = $unser_template_border_details['border_lwidth'];
        $border_twidth = $unser_template_border_details['border_twidth'];
        $border_bwidth = $unser_template_border_details['border_bwidth'];
        $border_color = $unser_template_border_details['border_color'];
        $border_radius = $unser_template_border_details['border_radius'];
        $border_bgcolor = $unser_template_border_details['border_bgcolor'];
        $border_bgimage = $unser_template_border_details['border_bgimage'];
        $container_width = $unser_template_border_details['container_width'];

        $user=$wpdb->get_results("SELECT  ID FROM {$wpdb->prefix}users ORDER BY ID desc LIMIT 1", ARRAY_A);
        $comment=$wpdb->get_results("SELECT comment_ID FROM {$wpdb->prefix}comments ORDER BY comment_ID desc LIMIT 1",ARRAY_A);
        $order = $wpdb->get_results("SELECT order_id FROM {$wpdb->prefix}wc_order_stats ORDER BY order_id desc LIMIT 1",ARRAY_A);
    
        foreach($user as $id){
            $user_id=$id['ID'];
        }
        foreach($comment as $id){
            $comment_id=$id['comment_ID'];
        }
        foreach($order as $id){
            $order_id=$id['order_id'];	
        }
        
        if(!empty($order_id)){
            $customer_note =$wpdb->get_results("SELECT comment_content FROM {$wpdb->prefix}comments where comment_post_ID = $order_id ");
            $count=count($customer_note);
            $num=$count-1;
            if(!empty($customer_note[$num]->comment_content)){
                $customer_note = $customer_note[$num]->comment_content; 
            }
            else {
                $customer_note = '';
            }
          
            $order = new \WC_Order( $order_id );
            $address = $order->get_address( 'billing' ); // returns an array
            $name = $address['first_name'];
            $last_name = $address['last_name'];
            $billing_first_name = $name;
            $billing_last_name = $last_name;
            $billing_email = $address['email'];
            $billing_phone= $address['phone'];
            $billing_country  = $address['country'];
            $billing_state = $address['state'];
            $billing_city = $address['city'];
            $billing_company = $address['company'];
            $billing_address_one = $address['address_1'];
            $billing_address_two= $address['address_2'];
            $billing_postcode = $address['postcode'];
    
            $saddress = $order->get_address( 'shipping' ); // returns an array
    
            $sname = $saddress['first_name'];
            $slast_name = $saddress['last_name'];
            $shipping_first_name = $sname;
            $shipping_last_name = $slast_name;
            $shipping_country = $saddress['country'];
            $shipping_state = $saddress['state'];
            $shipping_city = $saddress['city'];
            $shipping_company  = $saddress['company'];
            $shipping_address_one = $saddress['address_1'];
            $shipping_address_two = $saddress['address_2'];
            $shipping_postcode = $saddress['postcode'];
            $shipping_name = $shipping_first_name.''.$shipping_last_name;
            $customer_name = $billing_first_name.' '.$billing_last_name;
        }
        else{
            $customer_note = '';
            $name = $last_name = '';
            $billing_first_name = $billing_last_name = $billing_email = $billing_phone = $billing_country = $billing_state = $billing_city = $billing_company = $billing_address_one = $billing_address_two = $billing_postcode = '';
            $shipping_first_name = $shipping_last_name = $shipping_country = $shipping_state = $shipping_city = $shipping_company = $shipping_address_one = $shipping_address_two = $shipping_postcode = $shipping_name = $customer_name = '';
        }
            
     
        $login_url=wp_login_url();
        $blog_name = get_bloginfo();
        $userdata=get_userdata($user_id);
        $user_name=$userdata->user_login;
        $user_email=$userdata->user_email;
        $admin_email=get_option('admin_email');
        $site_url=get_option('siteurl');
        $current = wp_get_current_user();
        $admin_name = $current->user_login;
    
        if(!empty($comment_id)){
            $comment=get_comment($comment_id);
            $comment_author=$comment->comment_author;
            $comment_author_IP=$comment->comment_author_IP;
            if(!empty($comment->comment_author_IP)){
                $comment_author_domain=gethostbyaddr($comment->comment_author_IP);
            }
            else{
                $comment_author_domain ='';
            }
            $comments_counts = $wpdb->get_var( "SELECT COUNT(*) FROM {$wpdb->prefix}comments WHERE comment_approved = '0'" );
            $comment_author_email=$comment->comment_author_email;
            $comment_author_url=$comment->comment_author_url;
            $comment_content=$comment->comment_content;
            $approve_url=admin_url( "comment.php?action=approve&c={$comment_id}#wpbody-content" );
            $trash_url=admin_url( "comment.php?action=trash&c={$comment_id}#wpbody-content" );
            $spam_url=admin_url( "comment.php?action=spam&c={$comment_id}#wpbody-content" );
            $moderation_url=admin_url( 'edit-comments.php?comment_status=moderated#wpbody-content' );
            $post=get_post($comment->comment_post_ID);
            $post_title=$post->post_title;
            $permalink=get_permalink($post->ID);
        }
        else{
            $comment_author_domain=$spam_url=$comments_counts='';
            $comment_author=$comment_author_IP=$comment_author_email=$comment_author_url="";
            $comment_content=$approve_url=$trash_url=$moderation_url=$post=$post_title=$permalink='';
        }
        
        if($templateid==1){
            $key = get_password_reset_key( $userdata);
            $password = network_site_url( "wp-login.php?action=rp&key=$key&login=". rawurlencode($userdata->user_login), 'login' ) ;
            $value = str_replace('{user_name}',$user_name,$value);  
            $value = str_replace('{blog_name}',$blog_name,$value);
            $value = str_replace('{password}',$password,$value);
            $value = str_replace('{user_email}',$user_email,$value);
            $value = str_replace('href="www.google.com"','href="'.$login_url.'"',$value);
            $value = str_replace('{admin_email}',$admin_email,$value);
            $value = str_replace('{login_url}',$login_url,$value);
            $value = str_replace('{admin_name}',$admin_name,$value);
        }
       
        else if($templateid==2){
            $key = get_password_reset_key( $userdata);
            $password=network_site_url( "wp-login.php?action=rp&key=$key&login=" . rawurlencode( $userdata->user_login ), 'login' ) ;
            $value = str_replace('{user_name}',$user_name,$value); 
            $value = str_replace('{user_login}',$user_name,$value); 
            $value = str_replace('{blog_name}',$blog_name,$value);
            $value = str_replace('{password}',$password,$value);
            $value = str_replace('{resetpassword_url}',$password,$value);
            $value = str_replace('href="www.google.com"','href="'.$password.'"',$value);
            $value = str_replace('{login_url}',$login_url,$value);
            $value = str_replace('{site_url}',$site_url,$value);
            
        }
        else if($templateid==3){
    
            $value = str_replace('{post_title}',$post_title,$value);  
            $value = str_replace('{permalink}',$permalink,$value);
            $value =str_replace('href="www.google.com"','href="'.$permalink.'"',$value); 
            $value = str_replace('{blog_name}',$blog_name,$value);
            $value = str_replace('{login_url}',$login_url,$value);
            $value = str_replace('{comment_author}',$comment_author,$value);  
            $value = str_replace('{comment_author_IP}',$comment_author_IP,$value);  
            $value = str_replace('{comment_author_domain}',$comment_author_domain,$value);  
            $value= str_replace('{comment_author_email}',$comment_author_email,$value);  
            $value= str_replace('{comment_author_url}',$comment_author_url,$value);  
            $value = str_replace('{comment_content}',$comment_content,$value);
            $value = str_replace('{approve_url}',$approve_url,$value);
            $value = str_replace('{trash_url}',$trash_url,$value);
            $value = str_replace('{spam_url}',$spam_url,$value);
            $value = str_replace('{moderation_url}',$moderation_url,$value);
            $value =str_replace('{comments_counts}',$comments_counts,$value);
            $value = str_replace('{admin_name}',$admin_name,$value);
    
        }
        else {
            if(!empty($order)){
                $var = $order->get_date_created();
                $order_date = $var."date";
                $orderDate = date_i18n( wc_date_format(), strtotime( $order_date ) );
            }
            else{
                $orderDate = '';
            }
    
            $value = str_replace('{admin_name}',$admin_name,$value);
            $value = str_replace('{customer_name}',$customer_name,$value);
            $value = str_replace('{customer_note}',$customer_note,$value);
            $value = str_replace('{First_name}',$name,$value);
            $value = str_replace('{Last_name}',$last_name,$value);
    
            if(!empty($order)){
                $value = str_replace('{order_no}',$order->get_order_number(),$value);
            }
            else{
                $value = str_replace('{order_no}','0',$value);
            }
    
            $value = str_replace('{order_date}',$orderDate,$value);
            $value = str_replace('{blog_name}',get_bloginfo(),$value);
            $value = str_replace('{user_name}',$user_name,$value);
            $value =str_replace('{site_url}',$site_url,$value);
            $value = str_replace('{billing_email}',$billing_email,$value);
            $value = str_replace('{billing_phone}',$billing_phone,$value);
            $value = str_replace('{billing_country}',$billing_country,$value);
            $value = str_replace('{billing_state}',$billing_state,$value);
            $value = str_replace('{billing_city}',$billing_city,$value);
            $value = str_replace('{billing_company}',$billing_company,$value);
            $value = str_replace('{billing_address_1}',$billing_address_one,$value);
            $value = str_replace('{billing_address_2}',$billing_address_two,$value);
            $value = str_replace('{billing_postcode}',$billing_postcode,$value);
            $value = str_replace('{shipping_name}',$shipping_name,$value);
            $value = str_replace('{shipping_country}',$shipping_country,$value);
            $value = str_replace('{shipping_state}',$shipping_state,$value);
            $value = str_replace('{shipping_city}',$shipping_city,$value);
            $value = str_replace('{shipping_company}',$shipping_company,$value);
            $value = str_replace('{shipping_address_1}',$shipping_address_one,$value);
            $value = str_replace('{shipping_address_2}',$shipping_address_two,$value);
            $value = str_replace('{shipping_postcode}',$shipping_postcode,$value);
        }
        if($templateid =='1'){
            $templateName ='New Account';
        }
        if($templateid == '2'){
            $templateName ='Reset Password';
        }
        if($templateid == '3'){
            $templateName ='Blog Comment';
        }
        if($templateid == '4'){
            $templateName ='Product Delivered';
        }
        if($templateid == '5'){
            $templateName ='New Order';
        }
        if($templateid == '6'){
            $templateName ='Completed Order';
        }
        if($templateid == '13'){
            $templateName ='Note To Customer';
        }

        $fullarray = '';
        $fullarray .='
	        <html> 
	            <head> <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /> </head>';
		
		        $fullarray .='
                <body style="background:'.$get_template_bgcolor.'">
                        <table border="0" cellpadding="0" cellspacing="0" height="100%" width="100%"> 
                            <tr> 
                                <td> 
                                    <table border="0" cellpadding="0" cellspacing="0" width="100%" id="custom_template_container" style=" max-width:'.$container_width.'px;; height:740px; padding: 10px 10px 0; margin: auto;"> 
                                        <tr> 
                                            <td align="center" valign="top">';
                
                if(!empty($border_bgcolor)){
                    $fullarray .='<div id="sm_template_container" style="border-style: solid;border-top-width:'.$border_twidth.'px;border-right-width:'.$border_rwidth.'px;border-bottom-width:'.$border_bwidth.'px;border-left-width:'.$border_lwidth.'px;border-color:'.$border_color.';border-radius:'.$border_radius.'px;background-color:'.$border_bgcolor.';padding:25px;">';
                }
                else{
                    $fullarray .='<div id="sm_template_container" style="border-style: solid;border-top-width:'.$border_twidth.'px;border-right-width:'.$border_rwidth.'px;border-bottom-width:'.$border_bwidth.'px;border-left-width:'.$border_lwidth.'px;border-color:'.$border_color.';border-radius:'.$border_radius.'px;background-image:url('.$border_bgimage.');padding:25px;">';
                }
                                                
                $fullarray .=''.stripslashes($value).'
                                                </div>
                                            </td> 
                                        </tr> 
                                    </table> 
                                </td>
                            </tr> 
                        </table>	
			        </body> 
			</html>';

  
        $get_subject = $wpdb->get_var("SELECT subject FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = $templateid AND theme_id = $themeid AND status = 'temporary'");
        if(!empty($get_subject)){
            $testMail_subject = $get_subject;
        }else{
            $testMail_subject = "Hi.. This is a test mail from Email Design Studio Plugin";   
        }
        $test_mail_array=explode(',',$get_recipient_mail);
        foreach($test_mail_array as $test_mail_to){
            $customiser_obj = new SMFetchTemplate();
            $value = $customiser_obj->mailSendOption($test_mail_to, $testMail_subject, $fullarray);
            $date = $createdTime = gmdate('Y-m-d h:i:s');
            $current_user = wp_get_current_user();
            $login = $current_user->user_login;
            if (is_plugin_active('easy-wp-smtp/easy-wp-smtp.php')){
                $medium = 'SMTP';
            }
            else{
                $medium = 'PHP mailer';
            }

            if($value == "1"){
                $status = 'success';
            }
            else{
                $status = 'failure';
            }
            $wpdb->insert($wpdb->prefix . 'sm_email_log', array(
                'template_name' => $templateName,
                'user' => $login,
                'date' => $date,
                'status' => $status,
                'medium' => $medium
            ) , array(
                '%s',
                '%s',
                '%s',
                '%s',
                '%s'
            ));
			
			
		}
        if(!empty($test_mail_array)){
            foreach($test_mail_array as $test_mail_to){
            if (!preg_match("/^[a-zA-Z-' ]*$/",$test_mail_to)) {
                $val['success'] = 'true';    
            }
            else{
                $val['success'] = 'false';
            }
          }
        }
        else {
            $val['success'] = 'false';
        }
        echo json_encode($val);
        wp_die();

    }
    public function smmail_container_width(){

        $themeid = intval($_POST['themeid']);
        $templateid = intval($_POST['templateid']);

        global $wpdb;
        $get_template_border_details = $wpdb->get_var("SELECT container_details FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = $templateid AND theme_id = $themeid AND status = 'temporary'");
        $unser_template_border_details = json_decode($get_template_border_details, true);	

        $container_width = $unser_template_border_details['container_width'];
        $containerwidth['containerwidth'] = $container_width;
        echo json_encode($containerwidth);
	    wp_die();
    }

    public function sm_unhook_flatsome(){
        // Unhook flatsome issue.
        wp_dequeue_style( 'flatsome-customizer-preview' );
        wp_dequeue_script( 'flatsome-customizer-frontend-js' );
    }

    public function sm_customizer_live_preview()
    {

        wp_register_script('sm-theme-customizer', plugins_url('assets/js/sm-theme-customizer.js', __FILE__), array('jquery', 'customize-preview'));
        wp_enqueue_script('sm-theme-customizer');

    }

    public function sm_enqueue_function(){
        ?>
        <?php
        wp_register_script('sm-preview', plugins_url('assets/js/sm-preview.js', __FILE__), array('jquery', 'customize-preview'));
        wp_enqueue_script('sm-preview');
    }


	public function sm_unhook_divi() {
        // Divi Theme issue.
        remove_action( 'wp_footer', 'et_builder_get_modules_js_data' );
        remove_action( 'et_customizer_footer_preview', 'et_load_social_icons' );
    }

    public function sm_unhook_lifter() {
        // Unhook LLMs issue.
        wp_dequeue_script( 'llms' );
    }

    public static function active_woo_callback( $object ) {
      
        if ( ! isset( $object->setting->id ) ) {
            return true;
        }
        $id = $object->setting->id;
      
    }

    /**
     * Add settings
     *
     * @access public
     * @param object $wp_customize
     * @return void
     */
    public function add_settings( $wp_customize ) {
       
        // Iterate over settings
        foreach ( self::$instance->get_woo_settings() as $setting_key => $setting ) {
             // Add setting
            $wp_customize->add_setting(
                $setting_key,
                array(
                    'type'          => 'theme_mod',
                    'transport'     => 'postMessage',
                    'capability' => 'edit_theme_options',
                    'default'       => isset( $setting['default'] ) ? $setting['default'] : '',
                )
            );
        }
    }

    /**
     * Add controls, sections and panels
     *
     * @access public
     * @param object $wp_customize
     * @return void
     */
    public function add_controls( $wp_customize ) {

        // Iterate over settings
        foreach ( self::$instance->get_woo_settings() as $setting_key => $setting ) {

            // Maybe add section
            self::$instance->maybe_add_section( $wp_customize, $setting );

            // Maybe add panel
            self::$instance->maybe_add_panel( $wp_customize, $setting );

            // Get control class name (none, color, upload, image)
            $control_class = isset( $setting['control_type'] ) ? ucfirst( $setting['control_type'] ) . '_' : '';
          
            $control_class = 'WP_Customize_' . $control_class . 'Control';
         
            // Control configuration
            $control_config = array(
                'label'             => $setting['title'],
                'settings'          => $setting_key,
                'capability' => 'edit_theme_options',
                'priority'          => isset( $setting['priority'] ) ? $setting['priority'] : 10,    
            );

            // Description
            if ( ! empty( $setting['description'] ) ) {
                $control_config['description'] = $setting['description'];
            }

            // Add control to section
            if ( ! empty( $setting['section'] ) ) {
                $control_config['section'] = 'sm_mail_' . $setting['section'];
            }

            // Add control to panel
            if ( ! empty( $setting['panel'] ) ) {
                $control_config['panel'] = 'sm_mail_' . $setting['panel'];
            }
            // Add custom field type
            if ( ! empty( $setting['type'] ) ) {
                $control_config['type'] = $setting['type'];
            }
            // Add custom field type
            if ( ! empty( $setting['label'] ) ) {
                $control_config['label'] = $setting['label'];
            }

            // Add select field options
            if ( ! empty( $setting['choices'] ) ) {
                $control_config['choices'] = $setting['choices'];
            }
            // Input attributese
            if ( ! empty( $setting['input_attrs'] ) ) {
                $control_config['input_attrs'] = $setting['input_attrs'];
            }
        
            // Add control
            $wp_customize->add_control( new $control_class( $wp_customize, $setting_key, $control_config ) );
        }
    }

    public static function maybe_add_section( $wp_customize, $child ) {
        // Get sections
        $sections = self::$instance->get_sections();

        // Check if section is set and exists
        if ( ! empty( $child['section'] ) && isset( $sections[ $child['section'] ] ) ) {

            // Reference current section key
            $section_key = $child['section'];

            // Check if section was not added yet
            if ( ! in_array( $section_key, self::$sections_added, true ) ) {

                // Reference current section
                $section = $sections[ $section_key ];

                // Section config
                $section_config = array(
                    'title'     => $section['title'],
                    'priority'  => ( isset( $section['priority'] ) ? $section['priority'] : 10 ),
                );

                // Description
                if ( ! empty( $section['description'] ) ) {
                    $section_config['description'] = $section['description'];
                }

                // Maybe add panel
                self::maybe_add_panel( $wp_customize, $section );

                // Maybe add section to panel
                if ( ! empty( $section['panel'] ) ) {
                    $section_config['panel'] = 'sm_mail_' . $section['panel'];
                }

                // Register section
                $wp_customize->add_section( 'sm_mail_' . $section_key, $section_config );

                // Track which sections were added
                self::$sections_added[] = $section_key;
            }
        }
    }

    public static function get_sections() {
        // Define sections.
        if ( is_null( self::$sections ) ) {
            self::$sections = array(

                'template_type' => array(
                    'title'    => __( 'Prebuilt Templates', 'email-design-studio' ),
                    'priority' => 8,
                ),

                //Email Order
                'email_type' => array(
                    'title'    => __( 'Email Type', 'email-design-studio' ),
                    'priority' => 10,
                ),
    
                // Header
                'header_type' => array(
                    'title'    => __( 'Header', 'email-design-studio' ),
                    'priority' => 10,
                ),

                //Container
                'image_type' => array(
                    'title'    => __( 'Image', 'email-design-studio' ),
                    'panel'    => 'container',
                    'priority' => 10,
                ),
                'order_type' => array(
                    'title'    => __( 'Order Details', 'email-design-studio' ),
                    'panel'    => 'container',
                    'priority' => 10,
                ),
                'text_type' => array(
                    'title'    => __( 'Text', 'email-design-studio' ),
                    'panel'    => 'container',
                    'priority' => 10,
                ),
                'customer_type' => array(
                    'title'    => __( 'Customer Details', 'email-design-studio' ),
                    'panel'    => 'container',
                    'priority' => 10,
                ),
                'button_type' => array(
                    'title'    => __( 'Button', 'email-design-studio' ),
                    'panel'    => 'container',
                    'priority' => 10,
                ),
                'divider_type' => array(
                    'title'    => __( 'Divider', 'email-design-studio' ),
                    'panel'    => 'container',
                    'priority' => 10,
                ),
                'border_type' => array(
                    'title'    => __( 'Border Details', 'email-design-studio' ),
                    'panel'    => 'container',
                    'priority' => 10,
                ),
                
               

                'social_type' => array(
                    'title'    => __( 'Social Links', 'email-design-studio' ),
                    'panel'    => 'footer',
                    'priority' => 10,
                ),
                'textarea_type' => array(
                    'title'    => __( 'Footer Text', 'email-design-studio' ),
                    'panel'    => 'footer',
                    'priority' => 10,
                ),

               

                'test_mail_type' => array(
                    'title'    => __( 'Send Preview Test Mail', 'email-design-studio' ),
                    'priority' => 100,
                ),
                'smtp_type' => array(
                    'title'    => __( 'SMTP Settings', 'email-design-studio' ),
                    'priority' => 100,
                ),
            );

       
        
        }
        // Return sections.
        return self::$sections;
    }

    public static function maybe_add_panel( $wp_customize, $child ) {
        // Get panels
        $panels = self::$instance->get_panels();
        // Check if panel is set and exists
        if ( ! empty( $child['panel'] ) && isset( $panels[ $child['panel'] ] ) ) {

            // Reference current panel key
            $panel_key = $child['panel'];

            // Check if panel was not added yet
            if ( ! in_array( $panel_key, self::$panels_added, true ) ) {

                // Reference current panel
                $panel = $panels[ $panel_key ];

                // Panel config
                $panel_config = array(
                    'title'         => $panel['title'],
                    'priority'      => ( isset( $panel['priority'] ) ? $panel['priority'] : 10 ),
                    'capability'    => 'edit_theme_options',
                );

                // Panel description
                if ( ! empty( $panel['description'] ) ) {
                    $panel_config['description'] = $panel['description'];
                }

                // Register panel
                $wp_customize->add_panel( 'sm_mail_' . $panel_key, $panel_config );

                // Track which panels were added
                self::$panels_added[] = $panel_key;
            }
        }
    }

    public static function get_panels() {
        // Define panels.
        if ( is_null( self::$panels ) ) {
            self::$panels = array(
            
                //Container
                'container' => array(
                    'title'    => __( 'Container', 'email-design-studio' ),
                    'priority' => 40,
                ),

                // Footer.
                'footer' => array(
                    'title'    => __( 'Footer', 'email-design-studio' ),
                    'priority' => 40,
                ),
            );
        }

        // Return panels.
        return self::$panels;
    }

    /**
     * Remove unrelated components
     *
     * @access public
     * @param array  $components
     * @param object $wp_customize
     * @return array
     */
    public function remove_unrelated_components( $components, $wp_customize ) {
        // Iterate over components
        foreach ( $components as $component_key => $component ) {

            // Check if current component is own component
            if ( ! self::$instance->is_own_component( $component ) ) {
                unset( $components[ $component_key ] );
            }
        }

        // Return remaining components
        return $components;
    }

    /**
     * Remove unrelated sections
     *
     * @access public
     * @param bool   $active
     * @param object $section
     * @return bool
     */
    public function remove_unrelated_sections( $active, $section ) {
        // Check if current section is own section
        if ( ! self::$instance->is_own_section( $section->id ) ) {
            return false;
        }

        // We can override $active completely since this runs only on own Customizer requests
        return true;
    }

    /**
     * Check if current section is own section
     *
     * @access public
     * @param string $key
     * @return bool
     */
    public static function is_own_section( $key ) {
        // Iterate over own sections
        foreach ( self::$instance->get_sections() as $section_key => $section ) {
            if ( $key === 'sm_mail_' . $section_key ) {
                return true;
            }
        }

        // Section not found
        return false;
    }

    /**
     * Check if current component is own component
     *
     * @access public
     * @param string $component
     * @return bool
     */
    public static function is_own_component( $component ) {
        return false;
    }

    /**
     * Remove unrelated controls
     *
     * @access public
     * @param bool   $active
     * @param object $control
     * @return bool
     */
    public function remove_unrelated_controls( $active, $control ) {
        // Check if current control belongs to own section
        if ( ! self::$instance->is_own_section( $control->section ) ) {
            return false;
        }

        // We can override $active completely since this runs only on own Customizer requests
        return $active;
    }

    public static function get_woo_settings() {

        if ( is_null( self::$woo_settings ) ) {
           
            $email_text = array();

            //Template Details
            $email_text[ 'sm_templateload' ] = array(
                'title'         => __( 'Template_load', 'email-design-studio' ),
                'section'       => 'template_type',
                'control_type'  => 'mailTemplate',
            );

            //email type details
            $email_text[ 'email_type_list' ] = array(
                'title'         => __( 'Email Type', 'email-design-studio' ),
                'section'       => 'email_type',
                'control_type'  => 'EmailOrders',
            );
            $email_text[ 'email_log_list' ] = array(
                'title'         => __( 'Email Log', 'email-design-studio' ),
                'section'       => 'test_mail_type',
                'control_type'  => 'EmailLog',
            );


            //Header Details
            $email_text[ 'header_position' ] = array(
                'title'         => __( 'Header Image Position', 'email-design-studio' ),
                'type'          => 'select',
                'section'       => 'header_type',
                'default'       => self::$instance->get_default_value('header_position'),
                'priority'      => 5,
                'choices'       => array(
                                    'Left'   => __( 'Left', 'email-design-studio' ),
                                    'Center' => __( 'Center', 'email-design-studio' ),
                                    'Right'  => __( 'Right', 'email-design-studio' ),
                                ),
              
            );
            $email_text[ 'header_image_upload' ] = array(
                'title'        => __( 'Logo', 'email-design-studio' ),
                'control_type' => 'image',
                'section'      => 'header_type',
                'default'       => self::$instance->get_default_value('header_image_upload'),
                'priority'     => 5,
            );
            $email_text[ 'header_bgcolor' ] = array(
                'title'         => __( 'Background Color', 'email-design-studio' ),
                'type'          => 'color',
                'section'       => 'header_type',
                'default'       => self::$instance->get_default_value('header_bgcolor'),
                'priority'      => 5,
            );
            $email_text[ 'header_logo_width' ] = array(
                'title'         => __( 'Logo Width', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'header_type',
                'default'       => self::$instance->get_default_value('header_logo_width'),
                'priority'      => 5,
                'input_attrs' => array(
                    'step'  => 2,
                    'min'   => 10,
                    'max'   => 600,
                ),
            );
            $email_text[ 'header_logo_height' ] = array(
                'title'         => __( 'Logo Height', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'header_type',
                'default'       => self::$instance->get_default_value('header_logo_height'),
                'priority'      => 5,
                'input_attrs' => array(
                    'step'  => 2,
                    'min'   => 10,
                    'max'   => 600,
                ),
            );
            $email_text[ 'header_wsize' ] = array(
                'title'         => __( 'Width Size', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'header_type',
                'default'       => self::$instance->get_default_value('header_wsize'),
                'priority'      => 5,
                'input_attrs' => array(
                    'step'  => 2,
                    'min'   => 10,
                    'max'   => 600,
                ),
            );
           

             //Image Details
             $email_text[ 'image_position' ] = array(
                'title'         => __( 'Image Position', 'email-design-studio' ),
                'type'          => 'select',
                'section'       => 'image_type',
                'default'       => self::$instance->get_default_value('image_position'),
                'priority'      => 5,
                'choices'       => array(
                                    'Left'   => __( 'Left', 'email-design-studio' ),
                                    'Center'   => __( 'Center', 'email-design-studio' ),
                                    'Right'   => __( 'Right', 'email-design-studio' ),
                                ),
            );
          

            $email_text[ 'image_upload' ] = array(
                'title'        => __( 'Image Upload', 'email-design-studio' ),
                'control_type' => 'image',
                'section'      => 'image_type',
                'default'       => self::$instance->get_default_value('image_upload'),
                'priority'     => 5,
                // 'original'     => '',
                // 'transport'    => 'refresh',
            );

            $email_text[ 'image_bgcolor' ] = array(
                'title'         => __( 'Image Background Color', 'email-design-studio' ),
                'type'          => 'color',
                'section'       => 'image_type',
                'default'       => self::$instance->get_default_value('image_bgcolor'),
                'priority'      => 5,
            );
            $email_text[ 'image_width' ] = array(
                'title'         => __( 'Image Width', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'image_type',
                'default'       => self::$instance->get_default_value('image_width'),
                'priority'      => 5,
            );
            $email_text[ 'image_height' ] = array(
                'title'         => __( 'Image Height', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'image_type',
                'default'       => self::$instance->get_default_value('image_height'),
                'priority'      => 5,
            );
            $email_text[ 'image_wsize' ] = array(
                'title'         => __( 'Width Size', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'image_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('image_wsize'),
                'input_attrs' => array(
                    'step'  => 2,
                    'min'   => 10,
                    'max'   => 600,
                ),
            );
            $email_text[ 'image_top' ] = array(
                'title'         => __( 'top Size', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'image_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('image_top'),
                'input_attrs' => array(
                    'step'  => 1,
                    'min'   => 0,
                    'max'   => 30,
                ),
            );
            $email_text[ 'image_bottom' ] = array(
                'title'         => __( 'bottom Size', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'image_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('image_bottom'),
                'input_attrs' => array(
                    'step'  => 1,
                    'min'   => 0,
                    'max'   => 30,
                ),
            );
            $email_text[ 'image_rounded' ] = array(
                'title'         => __( 'rounded Size', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'image_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('image_rounded'),
                'input_attrs' => array(
                    'step'  => 1,
                    'min'   => 0,
                    'max'   => 100,
                ),
            );
            $email_text[ 'image_bcolor' ] = array(
                'title'         => __( 'Image Border Color', 'email-design-studio' ),
                'type'          => 'color',
                'section'       => 'image_type',
                'default'       => self::$instance->get_default_value('image_bcolor'),
                'priority'      => 5,
            );
            
            $email_text[ 'image_bsize' ] = array(
                'title'         => __( 'Image Border Size', 'email-design-studio' ),
                'type'          => 'select',
                'section'       => 'image_type',
                'default'       => self::$instance->get_default_value('image_bsize'),
                'priority'      => 5,
                'choices'       => array(
                                    'thin'   => __( 'thin', 'email-design-studio' ),
                                    'medium'   => __( 'medium', 'email-design-studio' ),
                                    'thick'   => __( 'thick', 'email-design-studio' ),
                                ),
            );
            $email_text[ 'image_border' ] = array(
                'title'         => __( 'Image Border', 'email-design-studio' ),
                'type'          => 'select',
                'section'       => 'image_type',
                'default'       => self::$instance->get_default_value('image_border'),
                'priority'      => 5,
                'choices'       => array(
                                    'None'   => __( 'None', 'email-design-studio' ),
                                    'Solid'   => __( 'Solid', 'email-design-studio' ),
                                    'Dashed'   => __( 'Dashed', 'email-design-studio' ),
                                    'Dotted'   => __( 'Dotted', 'email-design-studio' ),
                                    'Double'   => __( 'Double', 'email-design-studio' ),
                                    'Groove'   => __( 'Groove', 'email-design-studio' ),
                                    'Ridget'   => __( 'Ridget', 'email-design-studio' ),
                                    'Inset'   => __( 'Inset', 'email-design-studio' ),
                                    'Outset'   => __( 'Outset', 'email-design-studio' ),
                                ),
            );
           

            //Order Details
            $email_text[ 'order_fontstyle' ] = array(
                'title'         => __( 'Font Style', 'email-design-studio' ),
                'type'          => 'select',
                'section'       => 'order_type',
                'default'       => self::$instance->get_default_value('order_fontstyle'),
                'priority'      => 5,
                'choices'       => self::$instance->get_font_styles()
            );
            $email_text[ 'order_tr_bgcolor' ] = array(
                'title'         => __( 'Table Background Color', 'email-design-studio' ),
                'type'          => 'color',
                'section'       => 'order_type',
                'default'       => self::$instance->get_default_value('order_tr_bgcolor'),
                'priority'      => 5,
            );
            $email_text[ 'order_fontcolor' ] = array(
                'title'         => __( 'Font Color', 'email-design-studio' ),
                'type'          => 'color',
                'section'       => 'order_type',
                'default'       => self::$instance->get_default_value('order_fontcolor'),
                'priority'      => 5,
            );
            $email_text[ 'order_hr_color' ] = array(
                'title'         => __( 'Header Color', 'email-design-studio' ),
                'type'          => 'color',
                'section'       => 'order_type',
                'default'       => self::$instance->get_default_value('order_hr_color'),
                'priority'      => 5,
            );
            $email_text[ 'order_bgcolor' ] = array(
                'title'         => __( 'Background Color', 'email-design-studio' ),
                'type'          => 'color',
                'section'       => 'order_type',
                'default'       => self::$instance->get_default_value('order_bgcolor'),
                'priority'      => 5,
            );
            $email_text[ 'order_wsize' ] = array(
                'title'         => __( 'Width Size', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'order_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('order_wsize'),
                'input_attrs' => array(
                    'step'  => 2,
                    'min'   => 10,
                    'max'   => 600,
                ),
            );
           

            //Text Details
            
            $get_url = wp_unslash( $_SERVER['HTTP_REFERER'] );
            $url_components = parse_url($get_url); 
            parse_str($url_components['query'], $params); 

            if(isset($params['templateid'])){
                $template_id = $params['templateid'];
                $theme_id = $params['themeid'];
            }
            else{
                $template_id = 1;
                $theme_id = 1;
            }

            $get_maintext1 = get_option("sm_customizer_maintext_{$template_id}{$theme_id}1");
            $get_maintext1 = str_replace('<br>', "\n", $get_maintext1);
            $get_maintext2 = get_option("sm_customizer_maintext_{$template_id}{$theme_id}2");
            $get_maintext2 = str_replace('<br>', "\n", $get_maintext2);
        
            $email_text[ 'text_content1' ] = array(
                'title'         => __( 'MainText Content 1', 'email-design-studio' ),
                'type'          => 'textarea',
                'section'       => 'text_type',
                'priority'      => 5,
                'default'       => $get_maintext1,
            );

            $email_text[ 'text_fontcolor1' ] = array(
                'title'         => __( 'MainText Font Color 1', 'email-design-studio' ),
                'type'          => 'color',
                'section'       => 'text_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('text_fontcolor1'),
            );

            $email_text[ 'text_fontsize1' ] = array(
                'title'         => __( 'MainText Font Size 1', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'text_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('text_fontsize1'),
                'input_attrs' => array(
                    'step'  => 2,
                    'min'   => 0,
                    'max'   => 20,
                ),
            );

            $email_text[ 'text_fontstyle1' ] = array(
                'title'         => __( 'MainText Font Style 1', 'email-design-studio' ),
                'type'          => 'select',
                'section'       => 'text_type',
                'default'       => self::$instance->get_default_value('text_fontstyle1'),
                'priority'      => 5,
                'choices'       => self::$instance->get_font_styles()
            );
              

            $email_text[ 'text_bgcolor1' ] = array(
                'title'         => __( 'MainText Background Color 1', 'email-design-studio' ),
                'type'          => 'color',
                'section'       => 'text_type',
                'default'       => self::$instance->get_default_value('text_bgcolor1'),
                'priority'      => 5,
            );
           
            $email_text[ 'text_bgimage1' ] = array(
                'title'         => __( 'MainText Background image 1', 'email-design-studio' ),
                'control_type'          => 'image',
                'section'       => 'text_type',
                'default'       => self::$instance->get_default_value('text_bgimage1'),
                'priority'      => 5,
            );

            $email_text[ 'text_wsize1' ] = array(
                'title'         => __( 'MainText Width Size 1', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'text_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('text_wsize1'),
                'input_attrs' => array(
                    'step'  => 2,
                    'min'   => 10,
                    'max'   => 600,
                ),
            );
            $email_text[ 'text_top1' ] = array(
                'title'         => __( 'MainText top Size1', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'text_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('text_top1'),
                'input_attrs' => array(
                    'step'  => 1,
                    'min'   => 0,
                    'max'   => 30,
                ),
            );
            $email_text[ 'text_bottom1' ] = array(
                'title'         => __( 'MainText bottom Size1', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'text_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('text_bottom1'),
                'input_attrs' => array(
                    'step'  => 1,
                    'min'   => 0,
                    'max'   => 20,
                ),
            );
            
         
            $email_text[ 'text_content2' ] = array(
                'title'         => __( 'MainText Content 2', 'email-design-studio' ),
                'type'          => 'textarea',
                'section'       => 'text_type',
                'priority'      => 5,
                'default'       => $get_maintext2,
            );

            $email_text[ 'text_fontcolor2' ] = array(
                'title'         => __( 'MainText Font Color 2', 'email-design-studio' ),
                'type'          => 'color',
                'section'       => 'text_type',
                'default'       => self::$instance->get_default_value('text_fontcolor2'),
                'priority'      => 5,
            );

            $email_text[ 'text_fontsize2' ] = array(
                'title'         => __( 'MainText Font Size 2', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'text_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('text_fontsize2'),
                'input_attrs' => array(
                    'step'  => 2,
                    'min'   => 0,
                    'max'   => 20,
                ),
            );

            $email_text[ 'text_fontstyle2' ] = array(
                'title'         => __( 'MainText Font Style 2', 'email-design-studio' ),
                'type'          => 'select',
                'section'       => 'text_type',
                'default'       => self::$instance->get_default_value('text_fontstyle2'),
                'priority'      => 5,
                'choices'       => self::$instance->get_font_styles()
            );

            $email_text[ 'text_bgcolor2' ] = array(
                'title'         => __( 'MainText Background Color 2', 'email-design-studio' ),
                'type'          => 'color',
                'section'       => 'text_type',
                'default'       => self::$instance->get_default_value('text_bgcolor2'),
                'priority'      => 5,
            );

            $email_text[ 'text_bgimage2' ] = array(
                'title'         => __( 'MainText Background image 2', 'email-design-studio' ),
                'control_type'          => 'image',
                'section'       => 'text_type',
                'default'       => self::$instance->get_default_value('text_bgimage2'),
                'priority'      => 5,
            );

            $email_text[ 'text_wsize2' ] = array(
                'title'         => __( 'MainText Width Size2', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'text_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('text_wsize2'),
                'input_attrs' => array(
                    'step'  => 2,
                    'min'   => 10,
                    'max'   => 600,
                ),
            );
            $email_text[ 'text_top2' ] = array(
                'title'         => __( 'MainText top Size2', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'text_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('text_top2'),
                'input_attrs' => array(
                    'step'  => 1,
                    'min'   => 0,
                    'max'   => 20,
                ),
            );
            $email_text[ 'text_bottom2' ] = array(
                'title'         => __( 'MainText bottom Size2', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'text_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('text_bottom2'),
                'input_attrs' => array(
                    'step'  => 1,
                    'min'   => 0,
                    'max'   => 20,
                ),
            );
           
        
            //Customer Details
            $email_text[ 'customer_fontfamily' ] = array(
                'title'         => __( 'Font Family', 'email-design-studio' ),
                'type'          => 'select',
                'section'       => 'customer_type',
                'default'       => self::$instance->get_default_value('customer_fontfamily'),
                'priority'      => 5,
                'choices'       => self::$instance->get_font_styles()
            );
            $email_text[ 'customer_bgcolor' ] = array(
                'title'         => __( 'Customer Details Background Color', 'email-design-studio' ),
                'type'          => 'color',
                'section'       => 'customer_type',
                // 'default'       => self::$instance->get_default_value('customer_bgcolor'),
                'default'       => '#000000',
                'priority'      => 5,
            );
            $email_text[ 'customer_ftcolor' ] = array(
                'title'         => __( 'Customer Details Font Color', 'email-design-studio' ),
                'type'          => 'color',
                'section'       => 'customer_type',
                'default'       => self::$instance->get_default_value('customer_ftcolor'),
                'priority'      => 5,
            );
            $email_text[ 'customer_wsize' ] = array(
                'title'         => __( 'Width Size', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'customer_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('customer_wsize'),
                'input_attrs' => array(
                    'step'  => 2,
                    'min'   => 10,
                    'max'   => 600,
                ),
            );
           

            //Button Details
            $email_text[ 'button_link' ] = array(
                'title'         => __( 'Button Link', 'email-design-studio' ),
                'type'          => 'text',
                'section'       => 'button_type',
                'default'       => self::$instance->get_default_value('button_link'),
                'priority'      => 5,
            );
            $email_text[ 'button_text' ] = array(
                'title'         => __( 'Text', 'email-design-studio' ),
                'type'          => 'text',
                'section'       => 'button_type',
                'default'       => self::$instance->get_default_value('button_text'),
                'priority'      => 5,
            );
            $email_text[ 'button_color' ] = array(
                'title'         => __( 'Button Color', 'email-design-studio' ),
                'type'          => 'color',
                'section'       => 'button_type',
                'default'       => self::$instance->get_default_value('button_color'),
                'priority'      => 5,
            );
            $email_text[ 'button_position' ] = array(
                'title'         => __( 'Button Position', 'email-design-studio' ),
                'type'          => 'select',
                'section'       => 'button_type',
                'default'       => self::$instance->get_default_value('button_position'),
                'priority'      => 5,
                'choices'       => array(
                                    'Left'   => __( 'Left', 'email-design-studio' ),
                                    'Center' => __( 'Center', 'email-design-studio' ),
                                    'Right'  => __( 'Right', 'email-design-studio' ),
                                ),
            );
            $email_text[ 'button_bgcolor' ] = array(
                'title'         => __( 'Button Background Color', 'email-design-studio' ),
                'type'          => 'color',
                'section'       => 'button_type',
                'default'       => self::$instance->get_default_value('button_bgcolor'),
                'priority'      => 5,
            );
            $email_text[ 'button_height' ] = array(
                'title'         => __( 'Button Height', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'button_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('button_height'),
                'input_attrs' => array(
                    'step'  => 2,
                    'min'   => 0,
                    'max'   => 10,
                ),
            );
            $email_text[ 'button_radius' ] = array(
                'title'         => __( 'Button Radius', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'button_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('button_radius'),
                'input_attrs' => array(
                    'step'  => 2,
                    'min'   => 0,
                    'max'   => 20,
                ),
            ); 
            $email_text[ 'button_widthsize' ] = array(
                'title'         => __( 'Button Width', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'button_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('button_widthsize'),
                'input_attrs' => array(
                    'step'  => 2,
                    'min'   => 10,
                    'max'   => 500,
                ),
            );
            $email_text[ 'button_wsize' ] = array(
                'title'         => __( 'Width Size', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'button_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('button_wsize'),
                'input_attrs' => array(
                    'step'  => 2,
                    'min'   => 10,
                    'max'   => 600,
                ),
            );

            $email_text[ 'button_ftcolor' ] = array(
                'title'         => __( 'Button Font Color', 'email-design-studio' ),
                'type'          => 'color',
                'section'       => 'button_type',
                'default'       => self::$instance->get_default_value('button_ftcolor'),
                'priority'      => 5,
            );

          

            //Divider Details
            $email_text[ 'divider_width1' ] = array(
                'title'         => __( 'Divider Width 1', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'divider_type',
                'default'       => self::$instance->get_default_value('divider_width1'),
                'priority'      => 5,
                'input_attrs' => array(
                    'step'  => 2,
                    'min'   => 10,
                    'max'   => 600,
                ),
            );
            $email_text[ 'divider_height1' ] = array(
                'title'         => __( 'Divider Height 1', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'divider_type',
                'default'       => self::$instance->get_default_value('divider_height1'),
                'priority'      => 5
            ); 
            $email_text[ 'divider_color1' ] = array(
                'title'         => __( 'Divider Color 1', 'email-design-studio' ),
                'type'          => 'color',
                'section'       => 'divider_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('divider_color1'),
            );
            $email_text[ 'divider_bgcolor1' ] = array(
                'title'         => __( 'Divider Background Color 1', 'email-design-studio' ),
                'type'          => 'color',
                'section'       => 'divider_type',
                'default'       => self::$instance->get_default_value('divider_bgcolor1'),
                'priority'      => 5,
            );
            $email_text[ 'divider_wsize1' ] = array(
                'title'         => __( 'Width Size 1', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'divider_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('divider_wsize1'),
                'input_attrs' => array(
                    'step'  => 2,
                    'min'   => 10,
                    'max'   => 600,
                ),
            );
            $email_text[ 'divider_width2' ] = array(
                'title'         => __( 'Divider Width 2', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'divider_type',
                'default'       => self::$instance->get_default_value('divider_width2'),
                'priority'      => 5,
                'input_attrs' => array(
                    'step'  => 2,
                    'min'   => 10,
                    'max'   => 600,
                ),
            );
            $email_text[ 'divider_height2' ] = array(
                'title'         => __( 'Divider Height 2', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'divider_type',
                'default'       => self::$instance->get_default_value('divider_height2'),
                'priority'      => 5
            ); 
            $email_text[ 'divider_color2' ] = array(
                'title'         => __( 'Divider Color 2', 'email-design-studio' ),
                'type'          => 'color',
                'section'       => 'divider_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('divider_color2'),
            );
            $email_text[ 'divider_bgcolor2' ] = array(
                'title'         => __( 'Divider Background Color 2', 'email-design-studio' ),
                'type'          => 'color',
                'section'       => 'divider_type',
                'default'       => self::$instance->get_default_value('divider_bgcolor2'),
                'priority'      => 5,
            );
            $email_text[ 'divider_wsize2' ] = array(
                'title'         => __( 'Width Size 2', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'divider_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('divider_wsize2'),
                'input_attrs' => array(
                    'step'  => 2,
                    'min'   => 10,
                    'max'   => 600,
                ),
            );

           

            //Background Details
            $email_text['mail_subject'] =array(
                'title'         =>  __('Mail Subject','email-design-studio'),
                'type'          =>  'text',
                'section'       => 'border_type',
                'default'       => self::$instance->get_default_value('mail_subject'),
                'priority'      => 5,
            );
            $email_text[ 'sm_border_twidth' ] = array(
                'title'         => __( 'Border Top Width', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'border_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('sm_border_twidth'),
                'input_attrs' => array(
                    'step'  => 2,
                    'min'   => 1,
                    'max'   => 20,
                ),
            );
            $email_text[ 'sm_border_rwidth' ] = array(
                'title'         => __( 'Border Right Width', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'border_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('sm_border_rwidth'),
                'input_attrs' => array(
                    'step'  => 2,
                    'min'   => 1,
                    'max'   => 20,
                ),
            );
            $email_text[ 'sm_border_bwidth' ] = array(
                'title'         => __( 'Border Bottom Width', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'border_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('sm_border_bwidth'),
                'input_attrs' => array(
                    'step'  => 2,
                    'min'   => 1,
                    'max'   => 20,
                ),
            );
            $email_text[ 'sm_border_lwidth' ] = array(
                'title'         => __( 'Border Left Width', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'border_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('sm_border_lwidth'),
                'input_attrs' => array(
                    'step'  => 2,
                    'min'   => 1,
                    'max'   => 20,
                ),
            );
            $email_text[ 'sm_border_color' ] = array(
                'title'         => __( 'Border Color', 'email-design-studio' ),
                'type'          => 'color',
                'section'       => 'border_type',
                'default'       => self::$instance->get_default_value('sm_border_color'),
                'priority'      => 5,
            );
            $email_text[ 'sm_border_radius' ] = array(
                'title'         => __( 'Border Radius', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'border_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('sm_border_radius'),
                'input_attrs' => array(
                    'step'  => 2,
                    'min'   => 1,
                    'max'   => 20,
                ),
            );
            $email_text[ 'sm_border_bgcolor' ] = array(
                'title'         => __( 'Background Color', 'email-design-studio' ),
                'type'          => 'color',
                'section'       => 'border_type',
                'default'       => self::$instance->get_default_value('sm_border_bgcolor'),
                'priority'      => 5,
            );
            $email_text[ 'sm_border_bgimage' ] = array(
                'title'         => __( 'Background Image', 'email-design-studio' ),
                'control_type' => 'image',
                'section'      => 'border_type',
                'default'       => self::$instance->get_default_value('sm_border_bgimage'),
                'priority'     => 5,
            );
            $email_text[ 'sm_border_container_width' ] = array(
                'title'         => __( 'Container Width', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'border_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('sm_border_container_width'),
                'input_attrs' => array(
                    'step'  => 2,
                    'min'   => 100,
                    'max'   => 1000,
                ),
            );
          


             //Textarea Details
             $email_text[ 'textarea_entertext' ] = array(
                'title'         => __( 'Enter Text', 'email-design-studio' ),
                'type'          => 'text',
                'section'       => 'textarea_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('textarea_entertext'),
                
              
            );
            $email_text[ 'textarea_position' ] = array(
                'title'         => __( 'Text Position', 'email-design-studio' ),
                'type'          => 'select',
                'section'       => 'textarea_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('textarea_position'),
                'choices'       => array(
                                    'Left'   => __( 'Left', 'email-design-studio' ),
                                    'Center' => __( 'Center', 'email-design-studio' ),
                                    'Right'  => __( 'Right', 'email-design-studio' ),
                                ),
            );
            $email_text[ 'textarea_fontcolor' ] = array(
                'title'         => __( 'Font Color', 'email-design-studio' ),
                'type'          => 'color',
                'section'       => 'textarea_type',
                'default'       => self::$instance->get_default_value('textarea_fontcolor'),
                'priority'      => 5,
            );
            $email_text[ 'textarea_style' ] = array(
                'title'         => __( 'Font Style', 'email-design-studio' ),
                'type'          => 'select',
                'section'       => 'textarea_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('textarea_style'),
                'choices'       => self::$instance->get_font_styles()
            );
            $email_text[ 'textarea_size' ] = array(
                'title'         => __( 'Font Size', 'email-design-studio' ),
                'type'          => 'select',
                'section'       => 'textarea_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('textarea_size'),
                'choices'       => array(
                                    '8'   => __( '8', 'email-design-studio' ),
                                    '9'   => __( '9', 'email-design-studio' ),
                                    '10'   => __( '10', 'email-design-studio' ),
                                    '11'   => __( '11', 'email-design-studio' ),
                                    '12'   => __( '12', 'email-design-studio' ),
                                    '14'   => __( '14', 'email-design-studio' ),
                                    '16'   => __( '16', 'email-design-studio' ),
                                    '18'   => __( '18', 'email-design-studio' ),
                                    '20'   => __( '20', 'email-design-studio' ),
                                ),
            );
            $email_text[ 'textarea_bgcolor' ] = array(
                'title'         => __( 'Text Area Background Color', 'email-design-studio' ),
                'type'          => 'color',
                'section'       => 'textarea_type',
                'default'       => self::$instance->get_default_value('textarea_bgcolor'),
                'priority'      => 5,
            );
            $email_text[ 'textarea_wsize' ] = array(
                'title'         => __( 'Width Size', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'textarea_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('textarea_wsize'),
                'input_attrs' => array(
                    'step'  => 2,
                    'min'   => 10,
                    'max'   => 600,
                ),
            );
      
            //Social Links Details
            $email_text[ 'social_position' ] = array(
                'title'         => __( 'Icons Position', 'email-design-studio' ),
                'type'          => 'select',
                'section'       => 'social_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('social_position'),
                'choices'       => array(
                                    'Left'   => __( 'Left', 'email-design-studio' ),
                                    'Center'   => __( 'Center', 'email-design-studio' ),
                                    'Right'   => __( 'Right', 'email-design-studio' ),
                                ),
            );
            $email_text[ 'social_bgcolor' ] = array(
                'title'         => __( 'Link Background Color', 'email-design-studio' ),
                'type'          => 'color',
                'section'       => 'social_type',
                'default'       => self::$instance->get_default_value('social_bgcolor'),
                'priority'      => 5,
            );
            $email_text[ 'social_fblink' ] = array(
                'title'         => __( 'Facebook Link', 'email-design-studio' ),
                'type'          => 'text',
                'section'       => 'social_type',
                'default'       => self::$instance->get_default_value('social_fblink'),
                'priority'      => 5,
            );
            $email_text[ 'social_twlink' ] = array(
                'title'         => __( 'Twitter Link', 'email-design-studio' ),
                'type'          => 'text',
                'section'       => 'social_type',
                'default'       => self::$instance->get_default_value('social_twlink'),
                'priority'      => 5,
            );
            $email_text[ 'social_glink' ] = array(
                'title'         => __( 'Google+ Link', 'email-design-studio' ),
                'type'          => 'text',
                'section'       => 'social_type',
                'default'       => self::$instance->get_default_value('social_glink'),
                'priority'      => 5,
            );
            $email_text[ 'social_ldlink' ] = array(
                'title'         => __( 'Linkedin Link', 'email-design-studio' ),
                'type'          => 'text',
                'section'       => 'social_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('social_ldlink'),
            );
            $email_text[ 'social_sklink' ] = array(
                'title'         => __( 'Skype Link', 'email-design-studio' ),
                'type'          => 'text',
                'section'       => 'social_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('social_sklink'),
            );
            $email_text[ 'social_ytlink' ] = array(
                'title'         => __( 'Youtube Link', 'email-design-studio' ),
                'type'          => 'text',
                'section'       => 'social_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('social_ytlink'),
            );
            $email_text[ 'social_inlink' ] = array(
                'title'         => __( 'Instagram Link', 'email-design-studio' ),
                'type'          => 'text',
                'section'       => 'social_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('social_inlink'),
            );
            $email_text[ 'social_wsize' ] = array(
                'title'         => __( 'Width Size', 'email-design-studio' ),
                'control_type'  => 'rangevalue',
                'section'       => 'social_type',
                'priority'      => 5,
                'default'       => self::$instance->get_default_value('social_wsize'),
                'input_attrs' => array(
                    'step'  => 2,
                    'min'   => 10,
                    'max'   => 600,
                ),
            );
           
            //mail details
            $email_text[ 'mail_recipient' ] = array(
                'title'         => __( 'Preview Test Mail Recipient', 'email-design-studio' ),
                'control_type'  => 'sendTestMail',
                'section'       => 'test_mail_type',
                'description'   => __( 'Enter recipient for preview test emails', 'email-design-studio' ), 
               // 'default'       => self::$instance->get_default_value('mail_recipient'),
            );
            $get_smtp_credentials = get_option('swcm_smtp_credentials');
            $email_text[ 'smtp_username' ] = array(
                'title'         => __( 'SMTP Username', 'email-design-studio' ),
                'type'          => 'text',
                'section'       => 'smtp_type',
                'priority'      => 5,
                //'default'       => self::$instance->get_default_value('footers_text3'),
            );
            $email_text[ 'smtp_password' ] = array(
                'title'         => __( 'SMTP Password', 'email-design-studio' ),
                'type'          => 'password',
                'section'       => 'smtp_type',
                'priority'      => 5,
                //'default'       => self::$instance->get_default_value('footers_text3'),
            );
         


            self::$woo_settings = $email_text;
        }
        return self::$woo_settings;
    }

    public function get_font_styles(){
        return array(
            'Arial'   => __( 'Arial', 'email-design-studio' ),
            'Comic Sans'   => __( 'Comic Sans', 'email-design-studio' ),
            'Courier New'   => __( 'Courier New', 'email-design-studio' ),
            'Georgia'   => __( 'Georgia', 'email-design-studio' ),
            'Helvetica'   => __( 'Helvetica', 'email-design-studio' ),
            'Lucida'   => __( 'Lucida', 'email-design-studio' ),
            'Tahoma'   => __( 'Tahoma', 'email-design-studio' ),
            'Times New Roman'   => __( 'Times New Roman', 'email-design-studio' ),
            'Trebuchet MS '   => __( 'Trebuchet MS', 'email-design-studio' ),
            'Verdana '   => __( 'Verdana', 'email-design-studio' ),
            'Roboto '   => __( 'Roboto', 'email-design-studio' ),
            'Open Sans'   => __( 'Open Sans', 'email-design-studio' ),
        );
    }

    public function get_default_value($type){
        global $wpdb;
        $get_url = wp_unslash( $_SERVER['HTTP_REFERER'] );
        $url_components = parse_url($get_url); 
        parse_str($url_components['query'], $params); 
       
        if(isset($params['templateid'])){
            $templateid = $params['templateid'];
            $themeid = $params['themeid'];
        }
        else{
            $templateid = 1;
            $themeid = 1;
        }

        $get_template_details = $wpdb->get_var("SELECT template_details FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = $templateid AND theme_id = $themeid AND status = 'temporary'");
		$unser_template_details = json_decode($get_template_details, true);
	
        $template_details_array = array(
            'header_position' => array('parent' => 'header_details', 'child' => 'image_position'),
            'header_image_upload' => array('parent' => 'header_details', 'child' => 'image_url'),
            'header_bgcolor' => array('parent' => 'header_details', 'child' => 'bg_color'),
            'header_logo_width' => array('parent' => 'header_details', 'child' => 'width'),
            'header_logo_height' => array('parent' => 'header_details', 'child' => 'height'),
            'header_wsize' => array('parent' => 'header_details', 'child' => 'rwidth'),
            //'header_height' => array('parent' => 'header_details', 'child' => 'hrheight'),

            'text_fontcolor1' => array('parent' => "maindragtext_{$templateid}{$themeid}1", 'child' => 'ftcolor'),
            'text_fontcolor2' => array('parent' => "maindragtext_{$templateid}{$themeid}2", 'child' => 'ftcolor'),
            'text_fontsize1' => array('parent' => "maindragtext_{$templateid}{$themeid}1", 'child' => 'ftsize'),
            'text_fontsize2' => array('parent' => "maindragtext_{$templateid}{$themeid}2", 'child' => 'ftsize'),
            'text_fontstyle1' => array('parent' => "maindragtext_{$templateid}{$themeid}1", 'child' => 'ftstyle'),
            'text_fontstyle2' => array('parent' => "maindragtext_{$templateid}{$themeid}2", 'child' => 'ftstyle'),
            'text_bgcolor1' => array('parent' => "maindragtext_{$templateid}{$themeid}1", 'child' => 'bgcolor'),
            'text_bgimage1' => array('parent' => "maindragtext_{$templateid}{$themeid}1", 'child' => 'bgimage'),
            'text_bgcolor2' => array('parent' => "maindragtext_{$templateid}{$themeid}2", 'child' => 'bgcolor'),
            'text_bgimage2' => array('parent' => "maindragtext_{$templateid}{$themeid}2", 'child' => 'bgimage'),
            'text_wsize1' => array('parent' => "maindragtext_{$templateid}{$themeid}1", 'child' => 'rwidth'),
            'text_wsize2' => array('parent' => "maindragtext_{$templateid}{$themeid}2", 'child' => 'rwidth'),
            'text_top1' => array('parent' => "maindragtext_{$templateid}{$themeid}1", 'child' => 'top'),
            'text_top2' => array('parent' => "maindragtext_{$templateid}{$themeid}2", 'child' => 'top'),
            'text_bottom1' => array('parent' => "maindragtext_{$templateid}{$themeid}1", 'child' => 'bottom'),
            'text_bottom2' => array('parent' => "maindragtext_{$templateid}{$themeid}2", 'child' => 'bottom'),
            //'text_height1' => array('parent' => "maindragtext_{$templateid}{$themeid}1", 'child' => 'height'),
            //'text_height2' => array('parent' => "maindragtext_{$templateid}{$themeid}2", 'child' => 'height'),
           
            'image_position' => array('parent' => 'imageblockdrag', 'child' => 'img_position'),
            'image_upload' => array('parent' => 'imageblockdrag', 'child' => 'img_url'),
            'image_bgcolor' => array('parent' => 'imageblockdrag', 'child' => 'img_bgcolor'),
            'image_width' => array('parent' => 'imageblockdrag', 'child' => 'img_width'),
            'image_height' => array('parent' => 'imageblockdrag', 'child' => 'img_height'),
            'image_wsize' => array('parent' => 'imageblockdrag', 'child' => 'rwidth'),
            'image_top' => array('parent' => 'imageblockdrag', 'child' => 'top'),
            'image_bottom' => array('parent' => 'imageblockdrag', 'child' => 'bottom'),
            'image_rounded' => array('parent' => 'imageblockdrag','child' => 'rounded'),
            'image_border' => array('parent' => 'imageblockdrag','child' => 'border'),
            'image_bcolor' => array('parent' => 'imageblockdrag','child' => 'bcolor'),
            'image_bsize' => array('parent' => 'imageblockdrag','child' => 'bsize'),
            //'sm_image_height' => array('parent' => 'imageblockdrag', 'child' => 'height'),

            'button_link' => array('parent' => 'button_details', 'child' => 'link'),
            'button_text' => array('parent' => 'button_details', 'child' => 'text'),
            'button_color' => array('parent' => 'button_details', 'child' => 'color'),
            'button_position' => array('parent' => 'button_details', 'child' => 'position'),
            'button_bgcolor' => array('parent' => 'button_details', 'child' => 'bg_color'),
            'button_wsize' => array('parent' => 'button_details', 'child' => 'rwidth'),
            'button_height' => array('parent' => 'button_details', 'child' => 'bheight'),
            'button_radius' => array('parent' => 'button_details', 'child' => 'bradius'),
            //'sm_button_height' => array('parent' => 'button_details', 'child' => 'height'),
            'button_widthsize' => array('parent' => 'button_details', 'child' => 'bwidth'),
            'button_ftcolor' => array('parent' => 'button_details', 'child' => 'bftcolor'),

            'divider_width1' => array('parent' => "hr_details_{$templateid}{$themeid}1", 'child' => 'width'),
            'divider_width2' => array('parent' => "hr_details_{$templateid}{$themeid}2", 'child' => 'width'),
            'divider_height1' => array('parent' => "hr_details_{$templateid}{$themeid}1", 'child' => 'height'),
            'divider_height2' => array('parent' => "hr_details_{$templateid}{$themeid}2", 'child' => 'height'),
            'divider_color1' => array('parent' => "hr_details_{$templateid}{$themeid}1", 'child' => 'color'),
            'divider_color2' => array('parent' => "hr_details_{$templateid}{$themeid}2", 'child' => 'color'),
            'divider_bgcolor1' => array('parent' => "hr_details_{$templateid}{$themeid}1", 'child' => 'bgcolor'),
            'divider_bgcolor2' => array('parent' => "hr_details_{$templateid}{$themeid}2", 'child' => 'bgcolor'),
            'divider_wsize1' => array('parent' => "hr_details_{$templateid}{$themeid}1", 'child' => 'rwidth'),
            'divider_wsize2' => array('parent' => "hr_details_{$templateid}{$themeid}2", 'child' => 'rwidth'),
            //'sm_divider_height' => array('parent' => 'hr_details', 'child' => 'dvheight'),

            'textarea_entertext' => array('parent' => 'maintext_details', 'child' => 'text'),
            'textarea_position' => array('parent' => 'maintext_details', 'child' => 'position'),
            'textarea_fontcolor' => array('parent' => 'maintext_details', 'child' => 'color'),
            'textarea_style' => array('parent' => 'maintext_details', 'child' => 'style'),
            'textarea_size' => array('parent' => 'maintext_details', 'child' => 'size'),
            'textarea_bgcolor' => array('parent' => 'maintext_details', 'child' => 'bgcolor'),
            'textarea_wsize' => array('parent' => 'maintext_details', 'child' => 'rwidth'),
            //'textarea_height' => array('parent' => 'maintext_details', 'child' => 'height'),

            'social_position' => array('parent' => 'socialblockdrag', 'child' => 'position'),
            'social_bgcolor' => array('parent' => 'socialblockdrag', 'child' => 'bgcolor'),
            'social_fblink' => array('parent' => 'socialblockdrag', 'child' => 'fb'),
            'social_twlink' => array('parent' => 'socialblockdrag', 'child' => 'twitter'),
            'social_glink' => array('parent' => 'socialblockdrag', 'child' => 'google'),
            'social_ldlink' => array('parent' => 'socialblockdrag', 'child' => 'linkedin'),
            'social_sklink' => array('parent' => 'socialblockdrag', 'child' => 'skype'),
            'social_ytlink' => array('parent' => 'socialblockdrag', 'child' => 'youtube'),
            'social_inlink' => array('parent' => 'socialblockdrag', 'child' => 'instagram'),
            'social_wsize' => array('parent' => 'socialblockdrag', 'child' => 'rwidth'),
            //'social_height' => array('parent' => 'socialblockdrag', 'child' => 'height'),

            'order_fontstyle' => array('parent' => 'order_details', 'child' => 'ftfamily'),
            'order_tr_bgcolor' => array('parent' => 'order_details', 'child' => 'trbgcolor'),
            'order_fontcolor' => array('parent' => 'order_details', 'child' => 'ftcolor'),
            'order_hr_color' => array('parent' => 'order_details', 'child' => 'hrcolor'),
            'order_bgcolor' => array('parent' => 'order_details', 'child' => 'orbgcolor'),
            'order_wsize' => array('parent' => 'order_details', 'child' => 'rwidth'),
            //'order_height' => array('parent' => 'order_details', 'child' => 'height'),

            'customer_fontfamily' => array('parent' => 'customer_details', 'child' => 'style'),
            'customer_bgcolor' => array('parent' => 'customer_details', 'child' => 'bgcolor'),
            'customer_ftcolor' => array('parent' => 'customer_details', 'child' => 'ftcolor'),
            'customer_wsize' => array('parent' => 'customer_details', 'child' => 'rwidth'),
            //'customer_height' => array('parent' => 'customer_details', 'child' => 'height'),

        );
      
        if($type == 'background_bgcolor'){
            $get_bgcolor = $wpdb->get_var("SELECT background_color FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = $templateid AND theme_id = $themeid AND status = 'temporary'");
            return $get_bgcolor;
        }
        elseif($type == 'mail_subject'){
            $get_subject = $wpdb->get_var("SELECT subject FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = $templateid AND theme_id = $themeid AND status = 'temporary'");
            return $get_subject;
        }
        elseif(strpos($type, 'sm_border_') !== FALSE){
            $get_border_details = $wpdb->get_var("SELECT container_details FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = $templateid AND theme_id = $themeid AND status = 'temporary'");
            $unser_border_details = json_decode($get_border_details, true);
        
            $border_fields_array = array(
                'sm_border_twidth' => 'border_twidth',
                'sm_border_rwidth' => 'border_rwidth',
                'sm_border_bwidth' => 'border_bwidth',
                'sm_border_lwidth' => 'border_lwidth',
                'sm_border_color'  => 'border_color',
                'sm_border_radius' => 'border_radius',
                'sm_border_bgcolor'=> 'border_bgcolor',
                'sm_border_bgimage'=> 'border_bgimage',
                'sm_border_container_width' => 'container_width',
                //'sm_border_container_height' => 'container_height',
                //'sm_border_container_bgcolor' => 'container_bgcolor'
            );
            return $unser_border_details[$border_fields_array[$type]];
        }
        else{
            if(isset($unser_template_details[$template_details_array[$type]['parent']])){
                $unser_template_details[$template_details_array[$type]['parent']][$template_details_array[$type]['child']] = isset($unser_template_details[$template_details_array[$type]['parent']][$template_details_array[$type]['child']])?$unser_template_details[$template_details_array[$type]['parent']][$template_details_array[$type]['child']]:'';
                return $unser_template_details[$template_details_array[$type]['parent']][$template_details_array[$type]['child']];
            }   
        }
    }
}