<?php
/**
* Email Design Studio plugin file. 
*
* Copyright (C) 2010-2020, Smackcoders Inc - info@smackcoders.com 
*/

namespace Smackcoders\SMEMAILCUSTOM;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class SMMailSend
{
    protected static $instance = null;

    public static function getInstance() {
		if ( null == self::$instance ) {
			self::$instance = new self;
            self::$instance->doHooks();
		}
		return self::$instance;
	}

    public function doHooks(){
        remove_action( 'register_new_user', 'wp_send_new_user_notifications' );
        remove_action( 'edit_user_created_user', 'wp_send_new_user_notifications', 10, 2 );
        remove_action( 'comment_post', 'wp_new_comment_notify_moderator' );
        remove_action( 'comment_post', 'wp_new_comment_notify_postauthor' );
        remove_action('after_password_reset', 'wp_password_change_notification',10,2 );
        remove_action('password_reset', 'wp_password_change_notification',10,2 );
        add_filter('woocommerce_new_customer_note_notification', array(self::$instance,'email_subject'), 1, 1);
        add_action( 'woocommerce_new_order', array(self::$instance, 'sm_trigger_mail_new_order'), 10, 1 );
        add_action( 'woocommerce_order_status_changed' , array(self::$instance, 'sm_trigger_mail_on_status_changed') , 10, 3);
        add_filter('retrieve_password_message',array(self::$instance, 'sm_trigger_mail_lostpassword'),99, 4);
        add_action('password_reset', array(self::$instance, 'sm_trigger_mail_setpassword'), 10, 2);
        add_action( 'user_register' , array(self::$instance, 'sm_trigger_mail_on_register_user'), 10, 1 );
        add_action('comment_post', array(self::$instance, 'sm_trigger_mail_blog_comment'), 10, 2);
        add_filter( 'woocommerce_locate_template', array(self::$instance, 'sm_woocommerce_locate_template'), 10, 3 );
        add_filter( 'send_password_change_email', array(self::$instance,'sm_userprofile'), 10, 2 );
        add_action( 'wpcf7_before_send_mail', array(self::$instance, 'contactformmail'), 10, 1);
        add_filter( 'wpcf7_skip_mail', array(self::$instance,'skipmail'),10,2); 

        add_action( 'wpforms_process_complete', array(self::$instance, 'sm_customizer_wpforms_submission'), 10, 4 );
        add_filter( 'wpforms_email_message', array(self::$instance, 'sm_customizer_disable_email_message'), 10, 2 );
        add_action('woocommerce_order_status_completed', array(self::$instance,'completed_order'));
        add_action('woocommerce_order_status_processing', array(self::$instance,'processing_order'));
        add_filter('woocommerce_email_subject_customer_invoice', array(self::$instance,'filter_woocommerce_email_subject_customer_invoice'), 10, 2);
        add_action('woocommerce_email', array(self::$instance,'unhook_those_pesky_emails'));
    }
    public function unhook_those_pesky_emails($email_class)
    {
        remove_action('woocommerce_new_customer_note_notification', array(
            $email_class->emails['WC_Email_Customer_Note'],
            'trigger'
        ));
        remove_action('woocommerce_order_status_completed', array(
            $email_class->emails['WC_Email_Customer_Note'],
            'trigger'
        ));
        remove_action('woocommerce_order_status_pending_to_completed_notification', array(
            $email_class->emails['WC_Email_New_Order'],
            'trigger'
        ));
        remove_action('woocommerce_order_status_completed_notification', array(
            $email_class->emails['WC_Email_Customer_Completed_Order'],
            'trigger'
        ));
        remove_action('woocommerce_order_status_failed_to_completed_notification', array(
            $email_class->emails['WC_Email_New_Order'],
            'trigger'
        ));
        remove_action('woocommerce_order_status_pending_to_processing_notification', array(
            $email_class->emails['WC_Email_New_Order'],
            'trigger'
        ));
        remove_action('woocommerce_order_status_pending_to_processing_notification', array(
            $email_class->emails['WC_Email_Customer_Processing_Order'],
            'trigger'
        ));
        remove_action('woocommerce_order_status_processing', array(
            $email_class->emails['WC_Email_Customer_Processing_Order'],
            'trigger'
        ));
    }
    public function sm_userprofile($user_ID, $user_data ){
        $pass1 = sanitize_text_field($_POST['pass1']);
        $pass2 = sanitize_text_field($_POST['pass2']);
        $action = sanitize_text_field($_POST['action']);
        if ( empty( $pass1 ) || $pass1!== $pass2 ){
            return;
        }
        if($action!='createuser'){
            include_once(plugin_dir_path(__FILE__).'/emailTemplates/sm-reset-password.php');	
            // password changed...
            $new_pass = $pass1;
            $sm_email_subjectprofile = $wpdb->get_var("SELECT subject FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = $template_id AND theme_id = $active_theme_id ");  
            
            if(!empty($sm_email_subjectprofile)){
                $subject = $sm_email_subjectprofile;
            }else{
                $subject = "Password changed";
            }
            $user_email = sanitize_email($_POST['email']);
            $customiser_obj = new SMFetchTemplate();
            $value = $customiser_obj->mailSendOption($user_email, $subject, $message);
            if (is_plugin_active('easy-wp-smtp/easy-wp-smtp.php')){
                $medium = 'SMTP';
            }
            else{
                $medium = 'PHP mailer';
            }
            $date = $createdTime = gmdate('Y-m-d h:i:s');
            $current_user = wp_get_current_user();
            $login = $current_user->user_login;
            $templateName = 'Reset Password';
            if($value == "1"){
                $status = 'success';
            }
            else{
                $status = 'failure';
            }
            $wpdb->insert($wpdb->prefix . 'sm_email_log', array(
                'template_name' => $templateName,
                'user' => $login,
                'date' => $date,
                'status' => $status,
                'medium' => $medium
            ) , array(
                '%s',
                '%s',
                '%s',
                '%s',
                '%s'
            ));
        }
    }
    
    public function sm_trigger_mail_new_order($order_id){
        global $woocommerce;
        $mailer = $woocommerce->mailer();
        $order = new \WC_Order( $order_id );
        include_once( plugin_dir_path(__FILE__) .'/emailTemplates/sm-new-order.php');
        $to = get_option('admin_email');
        
        $sm_email_subject = $wpdb->get_var("SELECT subject FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = 5 AND theme_id = $active_theme_id ");
        if(!empty($sm_email_subject)){
            $admin_subject = $sm_email_subject;
        }
        else{
            $admin_subject = "New Order";
        }

         $user_mail_to = $order->get_billing_email();
        $mailer->send( $to, $admin_subject, $neworder_message );
        $mailer->send($user_mail_to,$admin_subject,$neworder_message);
    }

    public function sm_trigger_mail_blog_comment($comment_ID,$comment_Approved){
        include_once( plugin_dir_path(__FILE__).'/emailTemplates/sm-blog-comment.php');
       
        $to = get_option('admin_email');

        $sm_email_subject = $wpdb->get_var("SELECT subject FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = $template_id AND theme_id = $active_theme_id ");
        if(!empty($sm_email_subject)){
            $subject = $sm_email_subject;
        }
        else{
            $subject = "Blog Comments";
        }

        $customiser_obj = new SMFetchTemplate();
        $value = $customiser_obj->mailSendOption($to, $subject, $message);
        if (is_plugin_active('easy-wp-smtp/easy-wp-smtp.php')){
            $medium = 'SMTP';
        }
        else{
            $medium = 'PHP mailer';
        }
        $date = $createdTime = gmdate('Y-m-d h:i:s');
        $current_user = wp_get_current_user();
        $login = $current_user->user_login;
        $templateName = 'Blog Comment';
        if($value == "1"){
            $status = 'success';
        }
        else{
            $status = 'failure';
        }
        $wpdb->insert($wpdb->prefix . 'sm_email_log', array(
            'template_name' => $templateName,
            'user' => $login,
            'date' => $date,
            'status' => $status,
            'medium' => $medium
        ) , array(
            '%s',
            '%s',
            '%s',
            '%s',
            '%s'
        ));
    }

    public function sm_trigger_mail_on_status_changed( $order_id , $old_order_status , $new_order_status )
    {	
        global $woocommerce;
        $mailer = $woocommerce->mailer();
        $order = new \WC_Order( $order_id );
        if($new_order_status === 'product-delivered' ) {
                
            include_once(plugin_dir_path(__FILE__).'/emailTemplates/sm-product-delivered.php');
            $to = get_option('admin_email');
        
            $sm_email_subject = $wpdb->get_var("SELECT subject FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = 4 AND theme_id = $active_theme_id ");
            if(!empty($sm_email_subject)){
                $subject = $sm_email_subject;
            }
            else{
                $subject = sprintf( __( 'Your Order %s has been Delivered sucessfully' ), $order->get_order_number() );
            }		
        
            $date = $createdTime = gmdate('Y-m-d h:i:s');
            $current_user = wp_get_current_user();
            $login = $current_user->user_login;
            $templateName = 'product-delivered';
            $mail_to =$order->get_billing_email();
            $mail_content = $delivered_message;
            $mail_subject = $subject;
            if (is_plugin_active('easy-wp-smtp/easy-wp-smtp.php')){
                $value = $mailer->send( $mail_to, $subject, $delivered_message );
                $medium = 'SMTP';
            }
            else{
                $value = require('MailSendMailer.php');
                $medium = 'PHP mailer';
            }
            if($value == "1"){
                $status = 'success';
            }
            else{
                $status = 'failure';
            }
            $wpdb->insert($wpdb->prefix . 'sm_email_log', array(
                'template_name' => $templateName,
                'user' => $login,
                'date' => $date,
                'status' => $status,
                'medium' => $medium
            ) , array(
                '%s',
                '%s',
                '%s',
                '%s',
                '%s'
            ));
        }
        elseif($new_order_status == 'on-hold'){
            include_once(plugin_dir_path(__FILE__).'/emailTemplates/sm-onhold-order.php');
            $to = get_option('admin_email');
           
            $sm_email_subject = $wpdb->get_var("SELECT subject FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = 8 AND theme_id = $active_theme_id ");
            if(!empty($sm_email_subject)){
                $subject = $sm_email_subject;
            }
            else{
                $subject = "On Hold Order";
            }

            $headers = array('Content-Type: text/html; charset=UTF-8');
            $date = $createdTime = gmdate('Y-m-d h:i:s');
            $current_user = wp_get_current_user();
            $login = $current_user->user_login;
            $templateName = 'On Hold Order';
            $mail_to = $order->get_billing_email();
            $mail_content = $messages;
            $mail_subject = $subject;
            if (is_plugin_active('easy-wp-smtp/easy-wp-smtp.php')){
                $value = $mailer->send( $mail_to, $subject, $messages );
                $medium = 'SMTP';
            }
            else{
                $value = require('MailSendMailer.php');
                $medium = 'PHP mailer';
            }
            if($value == "1"){
                $status = 'success';
            }
            else{
                $status = 'failure';
            }
            $wpdb->insert($wpdb->prefix . 'sm_email_log', array(
                'template_name' => $templateName,
                'user' => $login,
                'date' => $date,
                'status' => $status,
                'medium' => $medium
            ) , array(
                '%s',
                '%s',
                '%s',
                '%s',
                '%s'
            ));
        }
        elseif($new_order_status == 'failed'){
            include_once(plugin_dir_path(__FILE__).'/emailTemplates/sm-failed-order.php');
            $to = get_option('admin_email');
            
            $sm_email_subject = $wpdb->get_var("SELECT subject FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = 9 AND theme_id = $active_theme_id ");
            if(!empty($sm_email_subject)){
                $subject = $sm_email_subject;
            }
            else{
                $subject = "Failed Order";
            }

            $headers = array('Content-Type: text/html; charset=UTF-8');
            $date = $createdTime = gmdate('Y-m-d h:i:s');
            $current_user = wp_get_current_user();
            $login = $current_user->user_login;
            $templateName = 'Failed Order';
            $mail_content = $failed_message;
            $mail_to = get_option('admin_email');
            $mail_subject = $subject;
            if (is_plugin_active('easy-wp-smtp/easy-wp-smtp.php')){
                $value = $mailer->send( $mail_to, $subject, $failed_message);
                $medium = 'SMTP';
            }
            else{
                $value = require('MailSendMailer.php');
                $medium = 'PHP mailer';
            }
            if($value == "1"){
                $status = 'success';
            }
            else{
                $status = 'failure';
            }
            $wpdb->insert($wpdb->prefix . 'sm_email_log', array(
                'template_name' => $templateName,
                'user' => $login,
                'date' => $date,
                'status' => $status,
                'medium' => $medium
            ) , array(
                '%s',
                '%s',
                '%s',
                '%s',
                '%s'
            ));
        }
        elseif($new_order_status == 'refunded'){
            include_once(plugin_dir_path(__FILE__).'/emailTemplates/sm-refunded-order.php');
            $to = get_option('admin_email');
            
            $sm_email_subject = $wpdb->get_var("SELECT subject FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = 11 AND theme_id = $active_theme_id");
            if(!empty($sm_email_subject)){
                $subject = $sm_email_subject;
            }
            else{
                $subject = "Refunded Order";
            }

            $headers = array('Content-Type: text/html; charset=UTF-8');
            $date = $createdTime = gmdate('Y-m-d h:i:s');
            $current_user = wp_get_current_user();
            $login = $current_user->user_login;
            $templateName = 'Refunded Order';
            $mail_to = $order->get_billing_email();
            $mail_content = $refunded_message;
            $mail_subject = $subject;
            if (is_plugin_active('easy-wp-smtp/easy-wp-smtp.php')){
                $value =  $mailer->send( $mail_to, $subject, $refunded_message );
                $medium = 'SMTP';
            }
            else{
                $value = require('MailSendMailer.php');
                $medium = 'PHP mailer';
            }
            if($value == "1"){
                $status = 'success';
            }
            else{
                $status = 'failure';
            }
            $wpdb->insert($wpdb->prefix . 'sm_email_log', array(
                'template_name' => $templateName,
                'user' => $login,
                'date' => $date,
                'status' => $status,
                'medium' => $medium
            ) , array(
                '%s',
                '%s',
                '%s',
                '%s',
                '%s'
            ));
        }
        elseif($new_order_status == 'cancelled'){
            include_once(plugin_dir_path(__FILE__).'/emailTemplates/sm-cancelled-order.php');
            $to = get_option('admin_email');
            
            $sm_email_subject = $wpdb->get_var("SELECT subject FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = 10 AND theme_id = $active_theme_id ");
          
            if(!empty($sm_email_subject)){
                $subject = $sm_email_subject;
            }
            else{
                $subject = "Cancelled Order";
            }
            $headers = array('Content-Type: text/html; charset=UTF-8');
            $mail_to = get_option('admin_email');
            $mail_content = $cancelled_message;
            $mail_subject = $subject;
            $date = $createdTime = gmdate('Y-m-d h:i:s');
            $current_user = wp_get_current_user();
            $login = $current_user->user_login;
            $templateName = 'Cancelled Order';
            if (is_plugin_active('easy-wp-smtp/easy-wp-smtp.php')){
                $value =  $mailer->send( $mail_to, $subject, $cancelled_message);
                $medium = 'SMTP';
            }
            else{
                $value = require('MailSendMailer.php');
                $medium = 'PHP mailer';
            }
            if($value == "1"){
                $status = 'success';
            }
            else{
                $status = 'failure';
            }
            $wpdb->insert($wpdb->prefix . 'sm_email_log', array(
                'template_name' => $templateName,
                'user' => $login,
                'date' => $date,
                'status' => $status,
                'medium' => $medium
            ) , array(
                '%s',
                '%s',
                '%s',
                '%s',
                '%s'
            ));
        }
    }

    public function sm_trigger_mail_lostpassword($message, $key, $user_login, $user_data){
        include_once(plugin_dir_path(__FILE__).'/emailTemplates/sm-reset-password.php');	
        $user_email = $user_data->user_email;
       
        $sm_email_subject = $wpdb->get_var("SELECT subject FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = $template_id AND theme_id = $active_theme_id ");
    
        if(!empty($sm_email_subject)){
            $subject = $sm_email_subject;
        }else{
            $subject = 'Reset Password';
        }


        $customiser_obj = new SMFetchTemplate();
        $value = $customiser_obj->mailSendOption($user_email, $subject, $message);
        if (is_plugin_active('easy-wp-smtp/easy-wp-smtp.php')){
            $medium = 'SMTP';
        }
        else{
            $medium = 'PHP mailer';
        }
        $date = $createdTime = gmdate('Y-m-d h:i:s');
        $current_user = wp_get_current_user();
        $login = $current_user->user_login;
        $templateName = 'Reset Password';
        if($value == "1"){
            $status = 'success';
        }
        else{
            $status = 'failure';
        }
        $wpdb->insert($wpdb->prefix . 'sm_email_log', array(
            'template_name' => $templateName,
            'user' => $login,
            'date' => $date,
            'status' => $status,
            'medium' => $medium
        ) , array(
            '%s',
            '%s',
            '%s',
            '%s',
            '%s'
        ));

      
    }

    public function sm_trigger_mail_setpassword($user_data, $newpass){
    
        include_once( plugin_dir_path(__FILE__).'/emailTemplates/sm-reset-password.php');	
        $admin_email = get_option('admin_email');

        $sm_email_subject = $wpdb->get_var("SELECT subject FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = $template_id AND theme_id = $active_theme_id ");
    
        if(!empty($sm_email_subject)){
            $subject = $sm_email_subject;
        }else{
            $subject = 'Password Changed';
        }

      
        // wp_mail($admin_email, $subject, $message, $headers);
        $customiser_obj = new SMFetchTemplate();
        $value = $customiser_obj->mailSendOption($admin_email, $subject, $message);
        if (is_plugin_active('easy-wp-smtp/easy-wp-smtp.php')){
            $medium = 'SMTP';
        }
        else{
            $medium = 'PHP mailer';
        }
        $date = $createdTime = gmdate('Y-m-d h:i:s');
        $current_user = wp_get_current_user();
        $login = $current_user->user_login;
        $templateName = 'Reset Password';
        if($value == "1"){
            $status = 'success';
        }
        else{
            $status = 'failure';
        }
        $wpdb->insert($wpdb->prefix . 'sm_email_log', array(
            'template_name' => $templateName,
            'user' => $login,
            'date' => $date,
            'status' => $status,
            'medium' => $medium
        ) , array(
            '%s',
            '%s',
            '%s',
            '%s',
            '%s'
        ));
       
        
    }

    public function sm_trigger_mail_on_register_user($user_id){
        include_once( plugin_dir_path(__FILE__).'/emailTemplates/sm-new-account.php');	
    
        //user mail
        $user_email = $user->user_email;
        $sm_email_subject = $wpdb->get_var("SELECT subject FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = $template_id AND theme_id = $active_theme_id ");
        
        if(!empty($sm_email_subject)){
            $subject = $sm_email_subject;
        }else{
            $subject = "New Account Register";
        }
        $headers = array('Content-Type: text/html; charset=UTF-8');
        $email = get_option('admin_email');
        // wp_mail($user_email, $subject, $messages, $headers);

        $customiser_obj = new SMFetchTemplate();
        $value = $customiser_obj->mailSendOption($user_email, $subject, $messages);
        if (is_plugin_active('easy-wp-smtp/easy-wp-smtp.php')){
            $medium = 'SMTP';
        }
        else{
            $medium = 'PHP mailer';
        }
        $date = $createdTime = gmdate('Y-m-d h:i:s');
        $current_user = wp_get_current_user();
        $login = $current_user->user_login;
        $templateName = 'New Account User';
        if($value == "1"){
            $status = 'success';
        }
        else{
            $status = 'failure';
        }
        $wpdb->insert($wpdb->prefix . 'sm_email_log', array(
            'template_name' => $templateName,
            'user' => $login,
            'date' => $date,
            'status' => $status,
            'medium' => $medium
        ) , array(
            '%s',
            '%s',
            '%s',
            '%s',
            '%s'
        ));
   
        //admin mail
        $admin_email = get_option('admin_email');
        if(!empty($sm_email_subject)){
            $subjectadmin = $sm_email_subject;
        }else{
            $subjectadmin = "New User Registration";
        }
        $customiser_obj = new SMFetchTemplate();
        $value = $customiser_obj->mailSendOption($admin_email, $subjectadmin, $messages);
        if (is_plugin_active('easy-wp-smtp/easy-wp-smtp.php')){
            $medium = 'SMTP';
        }
        else{
            $medium = 'PHP mailer';
        }
        $date = $createdTime = gmdate('Y-m-d h:i:s');
        $current_user = wp_get_current_user();
        $login = $current_user->user_login;
        $templateName = 'New Account Admin';
        if($value == "1"){
            $status = 'success';
        }
        else{
            $status = 'failure';
        }
        $wpdb->insert($wpdb->prefix . 'sm_email_log', array(
            'template_name' => $templateName,
            'user' => $login,
            'date' => $date,
            'status' => $status,
            'medium' => $medium
        ) , array(
            '%s',
            '%s',
            '%s',
            '%s',
            '%s'
        ));
    
    }

    public function sm_woocommerce_locate_template($template, $template_name, $template_path){
        global $woocommerce;

        $_template = wc_clean($template);
        if ( !$template_path ) $template_path = $woocommerce->template_url;
        $plugin_path  = plugin_dir_path(__FILE__) . '/emailTemplates/';

        // Look within passed path within the theme - this is priority
        $template = locate_template(
                array(
                    $template_path . $template_name,
                    $template_name
                     )
                );
    
        switch($template_name){
            case 'emails/admin-new-order.php':
                $email_template = self::$instance->active_template('New Order');
                break;
            case 'emails/customer-on-hold-order.php':
                $email_template = self::$instance->active_template('On Hold Order');
                break;
            case 'emails/admin-cancelled-order.php':
                $email_template = self::$instance->active_template('Cancelled Order');          
                break;
            case 'emails/admin-failed-order.php':
                $email_template = self::$instance->active_template('Failed Order');
                break;
            case 'emails/customer-completed-order.php':
                $template_name = 'sm-completed-order.php';
                $email_template = self::$instance->active_template('Completed Order');
                break;
            case 'emails/customer-invoice.php':
                $template_name = 'sm-customer-invoice.php';
                $email_template = self::$instance->active_template('Customer Invoice');
                break;
            case 'emails/customer-new-account.php':
                $template_name = 'sm-new-account.php';
                $email_template = self::$instance->active_template('New Account');
                break;
            case 'emails/customer-note.php':
                $template_name = 'sm-note-to-customer.php';
                $email_template = self::$instance->active_template('Note To The Customer');
                break;
            case 'emails/customer-processing-order.php':
                $template_name = 'sm-processing-order.php';
                $email_template = self::$instance->active_template('Processing Order');  
                break;
            case 'emails/customer-refunded-order.php':
                $email_template = self::$instance->active_template('Refunded Order');
                break;
            case 'emails/customer-reset-password.php':
                $email_template = self::$instance->active_template('Reset Password');
                break;
            case 'emails/product-delivered-order.php':
                $email_template = self::$instance->active_template('Product Delivered');
                break;                                    
        }
        if(isset($email_template) && ($email_template == "")){
            if ($template && file_exists( $plugin_path . $template_name ) )
            $template = $plugin_path . $template_name;
        } else{
    
            // Modification: Get the template from this plugin, if it exists
            if ( ! $template && file_exists( $plugin_path . $template_name ) )
            $template = $plugin_path . $template_name;
        }
        // Use default template
        if ( ! $template )
            $template = $_template;
    
        // Return what we found
        return $template;
    }

    public function active_template($action_name) {
        global $wpdb;
        $table_name = $wpdb->prefix . "sm_customiser_pro_table";
      
        $sql = "select template_name from ".$table_name." where template_type = '$action_name'";
        $resul = $wpdb->get_results($sql);
    
        if ($resul) {
            $value = $resul[0]->template_name;
            return 1;
        }else{
            return 1;	
        }
    }

    public function contactformmail( $wpcf7) {
	
        global $wpdb;
        $active_theme_id = get_option("sm_mail_contact_form_confirmation_mail_activate_template");
        $post_id = intval($_POST['_wpcf7']);
        $form_detail = $wpdb->get_results( $wpdb->prepare( "select ID,post_content from $wpdb->posts where ID=%d" , $post_id ) );
        $contact_post_content = $form_detail[0]->post_content;
        $fields = getTextBetweenBrackets( $contact_post_content );
        $i = 0;
        $contact_form_labels[0]='';
        $contactform_result_table ='';
        if($active_theme_id =="1"){
            $contactform_result_table .= '<table border=\"0\" cellpadding=\"10\" cellspacing=\"10\" style=\"width:100%\">
            <tbody>';
            foreach( $fields as $cfkey => $cfval )
            {
                if( preg_match( '/\s/' , $cfval ) )
                {
                    $final_arr = explode( ' ' , $cfval );
                    $contact_form_labels = rtrim( $final_arr[1],']' );
                    $contact_form_value = sanitize_text_field($_POST[$contact_form_labels]);
                    $contactform_result_table  .= '<tr>
                    <td><span style=\"font-size:18px\">'.$contact_form_labels.'</span></td>
                    <td><span style=\"font-size:18px\">'.$contact_form_value.'</span></td>
                    </tr>';
                    $i++;
                }
            }
            $contactform_result_table .= '</tbody></table>';
            update_option('sm_customizer_maintext_1412', $contactform_result_table);
        }
        if($active_theme_id =="2"){
            $contactform_result_table .= '<table border=\"0\" cellpadding=\"0\" cellspacing=\"0\" style=\"width:100%;background-color: rgb(255, 255, 255); border-color: rgb(255, 255, 255);\">
            <tbody>';
            foreach( $fields as $cfkey => $cfval )
            {
                if( preg_match( '/\s/' , $cfval ) )
                {
                    $final_arr = explode( ' ' , $cfval );
                    $contact_form_labels = rtrim( $final_arr[1],']' );
                    $contact_form_value = sanitize_text_field($_POST[$contact_form_labels]);
                    $contactform_result_table .='<tr style="line-height:20%">
                    <td style=\"background-color: rgb(242, 242, 242); border-color: rgb(242, 242, 242);\"><span style=\"font-size:14px\"><span style=\"font-family:Times New Roman,Times,serif\"><p style=\"text-align: center;\">'.$contact_form_labels.'</p></span></span></td>
                    <td style=\"background-color: rgb(242, 242, 242); border-color: rgb(242, 242, 242);\"><span style=\"font-size:14px\"><span style=\"font-family:Times New Roman,Times,serif\"><p style=\"text-align: center;\">'.$contact_form_value.'</p></span></span></td>
                    </tr>
                    <tr>
                    <td style=\"background-color: rgb(255, 255, 255); border-color: rgb(255, 255, 255);\">&nbsp;</td>
                    <td style=\"background-color: rgb(255, 255, 255); border-color: rgb(255, 255, 255);\">&nbsp;</td>
                    </tr>';

                    $i++;
                }
            }
            $contactform_result_table .= '</tbody></table>';
            update_option('sm_customizer_maintext_1423', $contactform_result_table);
        }

        if($active_theme_id =="3"){
            $contactform_result_table .= '<table align=\"center\" border=\"0\" cellpadding=\"5\" cellspacing=\"5\" style=\"width:80%\">
            <tbody>';
            foreach( $fields as $cfkey => $cfval )
            {
                if( preg_match( '/\s/' , $cfval ) )
                {
                    $final_arr = explode( ' ' , $cfval );
                    $contact_form_labels = rtrim( $final_arr[1],']' );
                    $contact_form_value = sanitize_text_field($_POST[$contact_form_labels]);
                    $contactform_result_table .='	<tr>
                    <td colspan=\"2\"style=\"white-space: nowrap;\"><span style=\"color:#ff8c00\"><span style=\"font-size:18px\">'.$contact_form_labels.'</span></span></td>
                    <td colspan=\"2\"><span style=\"color:#fff0f5\"><span style=\"font-size:18px\">'.$contact_form_value.'</span></span></td>
                    </tr>';

                    $i++;
                }
            }
            $contactform_result_table .= '</tbody></table>';
            update_option('sm_customizer_maintext_1432', $contactform_result_table);

        }
        include_once( plugin_dir_path(__FILE__).'/emailTemplates/sm-contactform-confirmationmail.php');	
        $sm_email_subjectuser = $wpdb->get_var("SELECT subject FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = $template_id AND theme_id = $active_theme_id ");
        if(!empty($sm_email_subjectuser)){
            $subjectuser = $sm_email_subjectuser;
        }else{
            $subjectuser = 'confirmation mail user';
        }
        $admin_email = get_option('admin_email');
        $urlparts = parse_url(home_url());
        $domain_name = $urlparts['host'];
        
        if($domain_name == 'localhost'){
            $headers[] = 'From: Wordpress<wordpress@mysite.com>';
            add_filter('wp_mail_content_type', function( $content_type ) {
                return 'text/html';
            });
            wp_mail($admin_email,$subjectuser,$message,$headers);
        }
        else{
            $headers = array('Content-Type: text/html;charset=UTF-8');
            wp_mail($admin_email,$subjectuser,$message,$headers);
        }	
    }

    public function getTextBetweenBrackets($post_content) {

        $data_type_array = array( 'text' , 'email' , 'date' , 'checkbox' , 'select' , 'url' , 'number' , 'textarea' , 'radio' , 'quiz' , 'file', 'acceptance' , 'hidden' , 'tel' , 'dynamichidden');

        $contact_labels = array();
        foreach( $data_type_array as $dt_key => $dt_val )
        {
                $patternn = "(\[$dt_val(\s|\*\s)(.*)\])";
                preg_match_all($patternn, $post_content, $matches);
                if( !empty( $matches[1] ))
                {
                        $contact_labels[] = $matches[0];
                }

                $i =0;
                $merge_array = array();
                foreach( $contact_labels as $cf7key => $cf7value )
                {
                        foreach( $cf7value as $cf_get_key => $cf_get_fields )
                        {
                        $merge_array[] = $cf_get_fields;
                        }
                }
        }
        return $merge_array;
    }

 
    public function skipmail($skip_mail, $contact_form ){
        $skip_mail = true;
        return $skip_mail;
    }

    public function sm_customizer_wpforms_submission($fields, $entry){
        global $wpdb;
        $post_id = $entry['id'];
    
        include_once(plugin_dir_path(__FILE__).'/emailTemplates/sm-wpforms-confirmationmail.php');	
        $to = get_option('admin_email');
        
        $get_template_id = $wpdb->get_results("SELECT template_id FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_type = 'WP Forms Confirmation Mail' AND activate = 'true' ");
        $template_id  = $get_template_id[0]->template_id;
        
        $sm_email_subjectuser = $wpdb->get_var("SELECT subject FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = $template_id AND theme_id = $active_theme_id ");
        
        if(!empty($sm_email_subject)){
            $subject = $sm_email_subject;
        }
        else{
            $subject = "WP Forms Confirmation Mail";
        }
        $headers = array('Content-Type: text/html; charset=UTF-8');
    
    
        $urlparts = parse_url(home_url());
        $domain_name = $urlparts['host'];
        if($domain_name == 'localhost'){
            $headers[] = 'From: Wordpress<wordpress@mysite.com>';
            add_filter('wp_mail_content_type', function( $content_type ) {
                return 'text/html';
            });
            wp_mail($to, $subject, $messages, $headers);
        }
        else{
            $headers = array('Content-Type: text/html;charset=UTF-8');
            wp_mail($to,$subject, $messages, $headers);
        }
    }

    public function sm_customizer_disable_email_message($message, $emails){
        return false;
    }

    public function email_subject($subject)
    {
        global $woocommerce;
        include_once(plugin_dir_path(__FILE__).'/emailTemplates/sm-note-to-customer.php');
        global $wpdb;
        $sm_email_subjectuser = $wpdb->get_var("SELECT subject FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = 13 AND theme_id = $active_theme_id");
        if (!empty($sm_email_subjectuser))
        {
            $subjects = $sm_email_subjectuser;
        }
        else
        {
            $subjects = "Note to customer ";
        }
        $urlparts = parse_url(home_url());
        $domain_name = $urlparts['host'];
        global $woocommerce;
        $mailer = $woocommerce->mailer();


        $date = $createdTime = gmdate('Y-m-d h:i:s');
        $current_user = wp_get_current_user();
        $login = $current_user->user_login;
        $mail_to = $order->get_billing_email();
        $mail_content = $messages;
        $mail_subject = $subjects;
        $templateName = 'Note to Customer';
        if (is_plugin_active('easy-wp-smtp/easy-wp-smtp.php')){
            $value =  $mailer->send($mail_to, $subjects, $messages);
            $medium = 'SMTP';
        }
        else{
            $value = require('MailSendMailer.php');
            $medium = 'PHP mailer';
        }
        if($value == "1"){
            $status = 'success';
        }
        else{
            $status = 'failure';
        }
        $wpdb->insert($wpdb->prefix . 'sm_email_log', array(
            'template_name' => $templateName,
            'user' => $login,
            'date' => $date,
            'status' => $status,
            'medium' => $medium
        ) , array(
            '%s',
            '%s',
            '%s',
            '%s',
            '%s'
        ));

    }

    public function completed_order($order_id)
    {
        $order = new \WC_Order($order_id);
        global $woocommerce;
        include_once(plugin_dir_path(__FILE__).'/emailTemplates/sm-completed-order.php');
        global $wpdb;
        $sm_email_subjectuser = $wpdb->get_var("SELECT subject FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = 6 AND theme_id = $active_theme_id");
        if (!empty($sm_email_subjectuser))
        {
            $subjects = $sm_email_subjectuser;
        }
        else
        {
            $subjects = "Completed Order ";
        }
        $urlparts = parse_url(home_url());
        $domain_name = $urlparts['host'];
        global $woocommerce;
        $mailer = $woocommerce->mailer();
        $date = $createdTime = gmdate('Y-m-d h:i:s');
        $current_user = wp_get_current_user();
        $login = $current_user->user_login;
        $templateName = 'Completed Order';
        $mail_to = $order->get_billing_email();
        $mail_content = $messages;
        $mail_subject = $subjects;
        if (is_plugin_active('easy-wp-smtp/easy-wp-smtp.php')){
            $value =  $mailer->send($mail_to, $subjects, $messages);
            $medium = 'SMTP';
        }
        else{
            $value = require('MailSendMailer.php');
            $medium = 'PHP mailer';
        }
        if($value == "1"){
            $status = 'success';
        }
        else{
            $status = 'failure';
        }
        $wpdb->insert($wpdb->prefix . 'sm_email_log', array(
            'template_name' => $templateName,
            'user' => $login,
            'date' => $date,
            'status' => $status,
            'medium' => $medium
        ) , array(
            '%s',
            '%s',
            '%s',
            '%s',
            '%s'
        ));

    }

    

    public function processing_order($order_id)
    {

        $order = new \WC_Order($order_id);
        global $woocommerce;
        global $wpdb;
        include_once(plugin_dir_path(__FILE__).'/emailTemplates/sm-processing-order.php');
        $sm_email_subjectuser = $wpdb->get_var("SELECT subject FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = 7 AND theme_id = $active_theme_id");
        if (!empty($sm_email_subjectuser))
        {
            $subjects = $sm_email_subjectuser;
        }
        else
        {
            $subjects = "Processing Order ";
        }
        $urlparts = parse_url(home_url());
        $domain_name = $urlparts['host'];
        global $woocommerce;
        $mailer = $woocommerce->mailer();
        $date = $createdTime = gmdate('Y-m-d h:i:s');
        $current_user = wp_get_current_user();
        $login = $current_user->user_login;
        $templateName = 'Processing Order';
        $mail_to = $order->get_billing_email();
        $mail_content = $messages;
        $mail_subject = $subjects;
        if (is_plugin_active('easy-wp-smtp/easy-wp-smtp.php')){
            $value =  $mailer->send($mail_to, $subjects, $messages);
            $medium = 'SMTP';
        }
        else{
            $value = require('MailSendMailer.php');
            $medium = 'PHP mailer';
        }
        if($value == "1"){
            $status = 'success';
        }
        else{
            $status = 'failure';
        }
        $wpdb->insert($wpdb->prefix . 'sm_email_log', array(
            'template_name' => $templateName,
            'user' => $login,
            'date' => $date,
            'status' => $status,
            'medium' => $medium
        ) , array(
            '%s',
            '%s',
            '%s',
            '%s',
            '%s'
        ));

    }



    public function filter_woocommerce_email_subject_customer_invoice($this_format_string_this_subject, $this_object)
    {
        global $woocommerce;
        global $wpdb;
        $active_theme_id = get_option("sm_mail_customer_invoice_activate_template");
        $sm_email_subjectuser = $wpdb->get_var("SELECT subject FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = 12 AND theme_id = $active_theme_id");
        if (!empty($sm_email_subjectuser))
        {
            $subjects = $sm_email_subjectuser;
        }
        else
        {
            $subjects = "customer invoice ";
        }
        return $subjects;
    }

// add the filter


}

SMMailSend::getInstance();