<?php
/**
* Email Design Studio plugin file. 
*
* Copyright (C) 2010-2020, Smackcoders Inc - info@smackcoders.com 
*/

namespace Smackcoders\SMEMAILCUSTOM;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'SMTemplatePage' ) ) {
class SMTemplatePage
{
    protected static $instance = null;


    public static function getInstance() {
		if ( null == self::$instance ) {
			self::$instance = new self;
		}
		return self::$instance;
	}

    public function __construct() {
        // Set up preview.
        add_action( 'parse_request', array( $this, 'set_up_preview' ) );
    }

    public function is_own_preview_request() {
		$server = wp_unslash( $_SERVER['HTTP_REFERER'] );
        $get_url = isset($server)?$server:'';
        $url_components = parse_url($get_url); 
		if(isset($url_components['query'])){
			parse_str($url_components['query'], $params); 
		}
       
    
		return isset( $params['sm-email-customize'] ) && '1' === $params['sm-email-customize'];
	}

    public function set_up_preview() {
       
        // Make sure this is own preview request.
        if ( ! self::$instance->is_own_preview_request() ) {
            return;
        }

        // Load main view.
    
        ?>
            <!DOCTYPE html>
                <head>
                    <meta charset="<?php bloginfo( 'charset' ); ?>" />
                    <meta name="viewport" content="width=device-width" />

                    <title><?php echo esc_html_e( 'Customiser Pro', 'email-design-studio' ); ?></title>
                </head>
                <body>

                    <div id="sm_preview_wrapper" style="display: block;">
                        <?php
                            self::$instance->print_preview_email();
                        ?>
                    </div>

                    <?php
                        do_action( 'woomail_footer' );
                        wp_footer();
                    ?>

                </body>
            </html>
        <?php

        // Do not load any further elements.
        exit;
    }

    

    public static function print_preview_email() {
        require_once(__DIR__.'/sm-preview.php' );
    }

    public function drag_template_details($dragid, $status, $source = null, $templateId = null, $themeId = null)
	{
		
        include_once(__DIR__.'/sm-fetch-template-details.php' );

        global $wpdb;
	
		if($status == 'via_save'){
			$template_type = sanitize_text_field($_REQUEST['status']);
			$template_id = intval($_REQUEST['id']);
			$theme_id = intval($_REQUEST['tempvalue']);
		}
		else{
			if(!empty($source)){
				$template_type = $source;
				$template_id = $templateId;
				$theme_id = $themeId;
			}
			else{
				$template_type = sanitize_text_field($_REQUEST['status']);
				$template_id = intval($_REQUEST['value']);
				$theme_id = intval($_REQUEST['tempvalue']);
			}
		}

		$template_type = 'template_details';
	
		$get_template_details = $wpdb->get_var("SELECT $template_type FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = $template_id AND theme_id = $theme_id AND status = 'temporary'");
		$unser_template_details = json_decode($get_template_details, true);
		if ($dragid == 'customer_details') {
		
			global $woocommerce, $post;
			$order_collection = new \WP_Query(array(
				'post_type'     => 'shop_order',
				'post_status'   => array_keys( wc_get_order_statuses() ),
				'posts_per_page'  => 1,
			));
			$order_collection = $order_collection->posts;
			
			if(isset(current($order_collection)->ID)){
				$latest_order = current($order_collection)->ID;
				$order_to_show = $latest_order;
				$order = new \WC_Order($order_to_show);
				$order_table_obj = new SMFetchTemplate();
			 	$customer_details = $order_table_obj->fetch_customer_details($order, $dragid, $template_type, $template_id, $theme_id, $source);
			 }
			else{
				$order_table_obj = new SMFetchTemplate();
				$customer_details = $order_table_obj->fetch_dummy_customer_details($dragid, $template_type, $template_id, $theme_id, $source);
			}

			if(!empty($source)){
				return $customer_details;
			}
			print_r($customer_details); //die();
	
		} 
		else if ($dragid == 'order_details'){
				
			global $woocommerce, $post;
			$order_collection = new \WP_Query(array(
				'post_type'     => 'shop_order',
				'post_status'   => array_keys( wc_get_order_statuses() ),
				'posts_per_page'  => 1,
			));
			$order_collection = $order_collection->posts;
			
			if(isset(current($order_collection)->ID)){
				$latest_order = current($order_collection)->ID;
				$order_to_show = $latest_order;
				$order = new \WC_Order($order_to_show);
				$order_id = $order->get_order_number();
				$order_table_obj = new SMFetchTemplate(); 
				if($theme_id == '9' || $theme_id == '3' || $theme_id == '4'){
					$order_details = $order_table_obj->fetch_order_details_theme9($order, $dragid, $template_type, $template_id, $theme_id, $source);
				}
				else{
					$order_details = $order_table_obj->fetch_order_details($order, $dragid, $template_type, $template_id, $theme_id, $source);
				}

			}
			else{
				$order_table_obj = new SMFetchTemplate(); 
				if($theme_id == '9' || $theme_id == '3' || $theme_id == '4'){
					$order_details = $order_table_obj->fetch_order_details_theme9('', $dragid, $template_type, $template_id, $theme_id, $source);
				}
				else{
					$order_details = $order_table_obj->fetch_dummy_order_details($dragid, $template_type, $template_id, $theme_id,$source);
				}

			}

			if(!empty($source)){
				return $order_details;
			}
			print_r($order_details);
		}

		else if (strpos($dragid,'hr_details_') !== FALSE) {
			$order_table_obj = new SMFetchTemplate(); 
			$divider_details = $order_table_obj->fetch_divider_details($dragid, $template_type, $template_id, $theme_id, $source);
			
			if(!empty($source)){
				return $divider_details;
			}
			print_r($divider_details);
		} 
		else if ($dragid == 'header_details') {
			$order_table_obj = new SMFetchTemplate(); 
			$header_details = $order_table_obj->fetch_header_details($dragid, $template_type, $template_id, $theme_id, $source);
			
			if(!empty($source)){
				return $header_details;
			}
			print_r($header_details);
		}
		else if (strpos($dragid, 'footer_details_') !== FALSE) {
			if (isset($footer_details)) 
				print_r($footer_details);
		}
		else if ($dragid == 'maintext_details') {
			$order_table_obj = new SMFetchTemplate(); 
			$maintext_details = $order_table_obj->fetch_text_details($dragid, $template_type, $template_id, $theme_id, $source);
			
			if(!empty($source)){
				return $maintext_details;
			}
			print_r($maintext_details); 
		}
	
		else if ($dragid == 'button_details') {
			$order_table_obj = new SMFetchTemplate(); 
			$button_details = $order_table_obj->fetch_button_details($dragid, $template_type, $template_id, $theme_id, $source);
			
			if(!empty($source)){
				return $button_details;
			}
			print_r($button_details);
		}
		else if (strpos($dragid, 'signatureblockdrag_') !== FALSE) {
			
			$order_table_obj = new SMFetchTemplate(); 
			$signature_details = $order_table_obj->fetch_signature_details($dragid, $template_type, $template_id, $theme_id, $source);
			
			if(!empty($source)){
				return $signature_details;
			}
			print_r($signature_details);                            
		}
		else if (strpos($dragid,'maindragtext_') !== FALSE) {
			
			$order_table_obj = new SMFetchTemplate(); 
			$maindrag_details = $order_table_obj->fetch_maindrag_details($dragid, $template_type, $template_id, $theme_id, $source);
			
			if(!empty($source)){
				return $maindrag_details;
			}
			print_r($maindrag_details);
		}
	
		else if ($dragid == 'imageblockdrag'){
			
			$order_table_obj = new SMFetchTemplate(); 
			$image_details = $order_table_obj->fetch_image_details($dragid, $template_type, $template_id, $theme_id, $source);
			
			if(!empty($source)){
				return $image_details;
			}
			print_r($image_details);
		}

		else if ($dragid == 'socialblockdrag') {
			
			$order_table_obj = new SMFetchTemplate();
			$social_details = $order_table_obj->fetch_social_details($dragid, $template_type, $template_id, $theme_id, $source);
			
			if(!empty($source)){
				return $social_details;
			}
			print_r($social_details);
		}
		else if (strpos($dragid, 'footerblockdrag_') !== FALSE) {
			
			$order_table_obj = new SMFetchTemplate(); 
			$footer_details = $order_table_obj->fetch_footer_details($dragid, $template_type, $template_id, $theme_id, $source);
			
			if(!empty($source)){
				return $footer_details;
			}
			print_r($footer_details);
		}
	}

	public function update_test_table($decode_template_details, $template_id, $theme_id){
		global $wpdb;
		$encode_template_details = json_encode($decode_template_details);
		$wpdb->update( $wpdb->prefix . 'sm_customiser_pro_table' , 
			array( 
				'template_details' => $encode_template_details,
			) , 
			array( 
				'template_id' => $template_id,
				'theme_id' => $theme_id,
				'status' => 'temporary'
			) 
		);
	}
	public function update_test_table_reset($decode_template_details_reset, $template_id, $theme_id){
		global $wpdb;
		$encode_template_details = json_encode($decode_template_details_reset);
		$wpdb->update( $wpdb->prefix . 'sm_customiser_pro_table' , 
			array( 
				'template_details' => $encode_template_details,
			) , 
			array( 
				'template_id' => $template_id,
				'theme_id' => $theme_id,
				'status' => 'permanent'
			) 
		);
	}

	public function update_test_table_bgcolor($background_color , $template_id,$theme_id){
		global $wpdb;
		$wpdb->update( $wpdb->prefix . 'sm_customiser_pro_table' , 
			array( 
				'background_color' => $background_color,
			) , 
			array( 
				'template_id' => $template_id,
				'theme_id' => $theme_id,
				'status' => 'temporary'
			) 
		);
	}

	public function update_test_table_subject($subject , $template_id,$theme_id){
		global $wpdb;
		$wpdb->update( $wpdb->prefix . 'sm_customiser_pro_table' , 
			array( 
				'subject' => $subject,
			) , 
			array( 
				'template_id' => $template_id,
				'theme_id' => $theme_id,
				'status' => 'temporary'
			) 
		);
	}

	public function update_border_details($key, $value , $templateid, $themeid){
		global $wpdb;

		$get_border_details = $wpdb->get_var("SELECT container_details FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = $templateid AND theme_id = $themeid");
		$decode_border_details = json_decode($get_border_details, true);

		$border_fields_array = array(
			'sm_border_twidth' => 'border_twidth',
			'sm_border_rwidth' => 'border_rwidth',
			'sm_border_bwidth' => 'border_bwidth',
			'sm_border_lwidth' => 'border_lwidth',
			'sm_border_color'  => 'border_color',
			'sm_border_radius' => 'border_radius',
			'sm_border_bgcolor'=> 'border_bgcolor',
			'sm_border_bgimage'=> 'border_bgimage',
			'sm_border_container_width' => 'container_width',
			//'sm_border_container_height' => 'container_height',
			//'sm_border_container_bgcolor' => 'container_bgcolor'
		);
		$decode_border_details[$border_fields_array[$key]] = $value;

		if($key == 'sm_border_bgimage'){
			$decode_border_details['border_bgcolor'] = '';
		}

		if($key == 'sm_border_bgcolor'){
			$decode_border_details['border_bgimage'] = '';
		}

		$encode_border_details = json_encode($decode_border_details);
		$wpdb->update( $wpdb->prefix . 'sm_customiser_pro_table' , 
			array( 
				'container_details' => $encode_border_details,
			) , 
			array( 
				'template_id' => $templateid,
				'theme_id' => $themeid,
				'status' => 'temporary'
			) 
		);
	}

	public function ordertable_fetch($orderno,$theme_id){

		$order = wc_get_order($orderno);
		// Get the order ID
		$order_no = $order->get_id();
		$sm_template_font_color = get_option('sm_template_font_color');
		$sm_template_font_family = get_option('sm_template_font_family');
		$sm_table_header = get_option('sm_table_header');
		$sm_table_body_background_color = get_option('sm_table_body_background_color');
		$sm_ordertable_background_color=get_option('sm_ordertable_background_color');
		if($theme_id == '9'){
			$base_color = '#0AD4C0';
		}
		elseif($theme_id == '3'){
			$base_color = '#B32E82';
		}
		elseif($theme_id == '4'){
			$base_color = '#E41F4D';
		}
		
		if(!isset($order_details))
			$order_details="";
			$order_details .= '
				<div> <div id="order_details" style="background-color:#'.$sm_ordertable_background_color.'; font-family:'.$sm_template_font_family.'; position:relative; " class="dragelementshowsmenu  edit_hover_class order_number" >
					<div style="line-height:1.3em;color:#'.$sm_template_font_color.';font-family:"Poppins", sans-serif;">
					</div> 
    				<tr> 
       					<td>     
							<h1 style="background-color:#'.$sm_ordertable_background_color.';font-size: larger;font-weight: bolder;padding-left: 11%; margin-top:0; padding-top:20px; color:black; ">Order No: #'.$order_no .' </h1>
    							<div id="sm_ordertable" style="background-color:#'.$sm_ordertable_background_color.';font-family:'.$sm_template_font_family.';color:#'.$sm_template_font_color.'; padding:20px 30px;">
       								<table onclick="" id="ordertableedit" style="background:#'.$sm_table_body_background_color.';margin:auto; border: 1px solid #eee;border-top:1px solid #eee;border-bottom:1px solid #eee;border-left:1px solid #eee;border-right:1px solid #eee; width:100%; max-width:700px;" cellspacing="10" cellpadding="10" border="1" frame=hsides rules=rows>
        								<thead>
        									<tr style="text-align:left;border: 1px solid #eee;">
         										<th id="swcm_table_color11" style="background:#' . $sm_table_header . ';color: #fff; text-transform: uppercase;font-size: 12px;color:black;padding: 12px;border-collapse: collapse;">';?> 
											<?php $order_details .= esc_html__( 'Product' , 'email-design-studio' ); ?> 
											<?php $order_details .='</th>
        										<th width="20%" id="swcm_table_color21" style="background:#'. $sm_table_header .';color: #fff; text-transform: uppercase;font-size: 12px;color:black;text-align:right; padding: 12px;border-collapse: collapse;">';?><?php $order_details .= esc_html__( 'Quantity', 'email-design-studio' ); $order_details .= '</th>
        										<th width="20%" id="swcm_table_color31" style="background:#'. $sm_table_header .';color: #fff; text-transform: uppercase;font-size: 12px;color:black; text-align:right;padding: 12px;border-collapse: collapse;">';?><?php $order_details .= esc_html__( 'Price', 'email-design-studio' ); $order_details .='</th>
                							</tr>
        								</thead>';
										if($theme_id == '9' || $theme_id == '3' || $theme_id == '4'){
											$order_details .= '<tbody id="swcm_template_font_color11" style="color:#'.$sm_template_font_color.';border: 1px solid '.$base_color.';padding: 12px 35px;border-collapse: collapse; font-family:inherit;">';
										}
										else{
											$order_details .= '<tbody id="swcm_template_font_color11" style="color:#'.$sm_template_font_color.';border: 1px solid #eee;padding: 12px 35px;border-collapse: collapse; font-family:inherit;">';
										}?>
										

			<?php 
			$order_data = $order->get_data(); // The Order data

			foreach ($order->get_items() as $item_id => $item_data) {
				// Get an instance of corresponding the WC_Product object
				$product = $item_data->get_product();
				$product_name = $product->get_name(); // Get the product name

				$item_quantity = $item_data->get_quantity(); // Get the item quantity

				$item_total = $item_data->get_total(); // Get the item line total
				$order_details .='
				<tr class="order_item" style=""> 
					<td class="td" style="text-align:left; padding:20px 10px; font-size:15px; border:none; border-bottom:1px solid #eee; color:inherit; vertical-align:middle; font-family: inherit;">'.$product_name.'</td> 
					<td class="td" style="text-align:right; padding:20px 10px; font-size:15px; border:none; border-bottom:1px solid #eee; color:inherit; vertical-align:middle; font-family: inherit;">'.$item_quantity.'</td> 
					<td class="td" style="text-align:right; padding:20px 10px; font-size:15px; border:none; border-bottom:1px solid #eee; color:inherit; vertical-align:middle; font-family: inherit;">'. number_format( $item_total, 2 ).'</td> 
				</tr>';
			}
			?>
			<?php $order_details .='
					</tbody>
									
					<tfoot id="swcm_template_font_color21" style="color:#'.$sm_template_font_color.';border: 1px solid #eee;border-top:1px solid #eee;padding: 12px 35px;border-collapse: collapse; font-size:16px;">';?> 
					<?php 	
					if ( $totals = $order->get_order_item_totals() ) { 
						$i = 0; 
						foreach ( $totals as $total ) { 
							$i++;
							$order_details .= '
								<tr id="swcm_template_font_color31" style="color:inherit;border:none;outline:none; border-collapse: collapse;"> 
									<td colspan="2" id="swcm_template_font_color41" style="text-align:right;border:none; outline:none; font-size:inherit; font-weight:bold; color:inherit;">';?> <?php 
							$order_details .= esc_html__($total['label'], 'email-design-studio'); 
							$order_details .= '</td> 
									<td style="border:none; text-align:right; outline:none; font-size:inherit; color:inherit;">';?><?php 
							$order_details .= $total['value'];$order_details .='</td></tr>';?> <?php 
						} 
					} 
					$order_details .= '</tfoot>';
					$order_details .= '</div></div>
					<div>
				</div>   
				</td>
			</tr>
			</table>
		</div>';
		
		return $order_details;
	}

	public function customer_table_fetch($orderno){

		$order = wc_get_order($orderno);
		$address = $order->get_address( 'billing' ); // returns an array
		$name = $address['first_name'];
		$last_name = $address['last_name'];
		$billing_first_name = $name;
		$billing_last_name = $last_name;
		$billing_email= $address['email'];
		$billing_phone = $address['phone'];
		$billing_country  = $address['country'];
		$billing_state = $address['state'];
		$billing_city = $address['city'];
		$billing_address_one = $address['address_1'];
		$billing_address_two = $address['address_2'];
		$billing_postcode = $address['postcode'];

		//Shipping Section
		$saddress = $order->get_address( 'shipping' );
		$sname = $saddress['first_name'];
		$slast_name = $saddress['last_name'];
		$shipping_first_name = $sname;
		$shipping_last_name = $slast_name;
		$shipping_country = $saddress['country'];
		$shipping_state = $saddress['state'];
		$shipping_city = $saddress['city'];
		$shipping_company  = $saddress['company'];
		$shipping_address_one = $saddress['address_1'];
		$shipping_address_two = $saddress['address_2'];
		$shipping_postcode = $saddress['postcode'];

		$sm_cust_font_color =  get_option('sm_cust_font_color');
		$sm_cust_body_background_color = get_option('sm_cust_body_background_color');
		$sm_cust_font_family = get_option('sm_cust_font_family');

		if(!isset($customer_details))
			$customer_details="";
		$customer_details .= '
		<div id="customer_details" class="dragelementshowsmenu edit_hover_class order_number" style="position:relative;';

		$customer_details.='" >

			<div id="custdetailscol" style="padding:20px 50px; font-size:16px; font-family:'.$sm_cust_font_family.';color:#'.$sm_cust_font_color.';background-color:#'.$sm_cust_body_background_color.'">

			<h3 style="font-size:18px; color:#'.$sm_cust_font_color.'; font-weight:bolder; font-family:inherit; padding-bottom: 10px;border-bottom: 1px solid #c5c5c5;">';$customer_details .=  esc_html__("Customer Details", 'email-design-studio'); $customer_details .= '</h3>';?>

			<?php if ( isset($billing_email) ) : 
			$customer_details .= '<p> <div> <strong> '; $customer_details .= esc_html__( "Email", 'email-design-studio'); 
			$customer_details .= ':</strong> '; $customer_details .=  $billing_email;
			$customer_details .= '</p>';?>
			<?php endif; ?>
				<?php if (isset($billing_phone) ) :
				$customer_details .= '<p><div><strong> ';
				$customer_details .= esc_html__( 'Telephone', 'email-design-studio' ); 
				$customer_details .= ':</strong> '; $customer_details .= $billing_phone; 
				$customer_details .= '</p> </div></div>';
				endif; ?>

			<?php 

			if ( $order->get_formatted_billing_address() || $order->get_formatted_shipping_address() ) : 

			$customer_details .= '<table cellpadding="0" cellspacing="0" border="0" width="100%" style="margin-top: 50px; font-size:16px;">
				<tbody><tr>
					<td width="25%" valign="top" style="  padding:20px 20px 20px 0px;">
						<p style="font-size:18px; font-weight:bolder; padding-bottom: 10px;border-bottom: 1px solid #c5c5c5;"><strong> ';  
						$customer_details .= esc_attr__("Billing address", 'email-design-studio'); 
						$customer_details .= ':</strong></p>
							<div style="border-style: solid;border:none; font-size:15px;">
								<p style="font-size:inherit;">  '; $customer_details .= $billing_first_name . $billing_last_name; $customer_details .= '</p> 
								<p style="font-size:inherit;"> '; $customer_details .= $billing_address_one; $customer_details.= ','; $customer_details .= $billing_address_one; $customer_details .= '</p>
								<p style="font-size:inherit;">'; $customer_details .= $billing_city; $customer_details.= '-'; $customer_details .= $billing_postcode; $customer_details .= '</p> 
								<p style="font-size:inherit;">'; $customer_details .= $billing_state; $customer_details.= ','; $customer_details .= $billing_country; $customer_details .= '</p> 
							</div> <br>
					</td>';
					$customer_details .= '<td width="25%" valign="top" style="  padding:20px 0px 20px 20px;">
						<p style="font-size:18px; font-weight:bolder; padding-bottom: 10px;border-bottom: 1px solid #c5c5c5;"><strong> '; 
						$customer_details .= esc_attr__("Shipping address", 'email-design-studio'); 
						$customer_details .= ':</strong></p>
							<div style="border-style: solid;border:none; font-size:15px;">
								<p style="">  '; $customer_details .= $shipping_first_name . $shipping_last_name; $customer_details .= '</p>'; 
								if(!empty($shipping_address_one)) {  
									$customer_details.= '<p style="font-size:inherit;"> ';
									$customer_details .= $shipping_address_one; 
									$customer_details.= ','; 
									$customer_details .= $shipping_address_two; 
									$customer_details .= '</p>'; 
								}
								if(!empty($shipping_city)) {
									$customer_details.=' <p style="font-size:inherit;">'; $customer_details .= $shipping_city; $customer_details.= '-'; $customer_details .= $shipping_postcode; $customer_details .= '</p>'; 
								}
								if(!empty($shipping_state)) {
									$customer_details .= '<p style="font-size:inherit;">'; $customer_details .= $shipping_state; $customer_details.= ','; $customer_details .= $shipping_country; $customer_details .= '</p> '; 
								}

				$customer_details .= '</div>                        
					</tr><tbody>
					</table></div> ';
				endif; 
				$customer_details .= ' </div> ';

		return $customer_details;
	}

	public function fetch_order_prod($order, $mode)
	{
		$items = $order->get_items();
		foreach ( $items as $item ) {
			if($mode == 'product_id'){
				$prod = $item['product_id'];
			}
			if($mode == 'product_qty'){
				$prod = $item['quantity'];
			}
			if($mode == 'name'){
				$prod = $item['name'];

			}
			if($mode == 'total'){
				$prod =  $item['total'];
			}

			if(!isset($order_prod))
				$order_prod="";
				$order_prod .='<table  cellpadding="0" cellspacing="0" border="0" width="100%" >
					<tr>';?>
						<?php $order_prod .= $prod; ?>
						<?php $order_prod .='';?>
						<?php do_action( 'woocommerce_email_after_order_table', $order, true, false ); 
						$order_prod .= '
					</tr>
				</table>';
		}
		$order_prod = isset($order_prod)?$order_prod:'';
		return $order_prod;
	}

	public function fetch_total_prod($order, $mode){
		$taddress = $order->get_order_item_totals();
		if($mode == 'subtotal'){
			$subtotal = $taddress['cart_subtotal'];
			$tot = $subtotal['value'];
		}
		if($mode == 'total'){
			$stotal = $taddress['order_total'];
			$tot = $stotal['value'];
		}
		if($mode == 'pay'){
			$tot = get_post_meta( $order->get_order_number(), '_payment_method_title', true );
		}
		$order_tot = $tot;
		return $order_tot;
	}

	public function get_details($orderno, $template_id, $active_theme_id){
		global $wpdb;
		$order = wc_get_order($orderno);
		$address = $order->get_address( 'billing' ); // returns an array
		$name = $address['first_name'];
		$last_name = $address['last_name'];
		$billing_first_name = $name;
		$billing_last_name = $last_name;
		$billing_email = $address['email'];
		$billing_phone = $address['phone'];
		$billing_country  = $address['country'];
		$billing_state = $address['state'];
		$billing_city = $address['city'];
		$billing_company = $address['company'];
		$billing_address_one = $address['address_1'];
		$billing_address_two = $address['address_2'];
		$billing_postcode = $address['postcode'];
		//Shipping Section
		$saddress = $order->get_address( 'shipping' ); // returns an array
		$sname = $saddress['first_name'];
		$slast_name = $saddress['last_name'];
		$shipping_first_name = $sname;
		$shipping_last_name = $slast_name;
		$shipping_country = $saddress['country'];
		$shipping_state = $saddress['state'];
		$shipping_city = $saddress['city'];
		$shipping_company  = $saddress['company'];
		$shipping_address_one = $saddress['address_1'];
		$shipping_address_two = $saddress['address_2'];
		$shipping_postcode = $saddress['postcode'];
		$var = $order->get_date_created();
		$order_date = $var."date";
		$shipping_name = $shipping_first_name.''.$shipping_last_name;
		$customer_name = $billing_first_name.' '.$billing_last_name;
		$current_user = wp_get_current_user();
		$user_login = $current_user->user_login;
		
		$value = '';
		$get_template_details = $wpdb->get_var("SELECT template_details FROM {$wpdb->prefix}sm_customiser_pro_table WHERE template_id = $template_id AND theme_id = $active_theme_id ");
		$unser_template_details = json_decode($get_template_details, true);	
		$customiser_obj = new SMTemplatePage();

		foreach($unser_template_details as $template_key => $template_value){
			$dragid=$template_key;
			if($dragid == 'order_details'){
				$order_table_obj = new SMFetchTemplate(); 
				if($active_theme_id == '9' || $active_theme_id == '3' || $active_theme_id == '4'){
					$value .= $order_table_obj->fetch_order_details_theme9($order, $template_key, 'template_details', $template_id, $active_theme_id, 'template_details');
				}
				else{
					$value .= $order_table_obj->fetch_order_details($order, $template_key, 'template_details', $template_id, $active_theme_id, 'template_details');
				}
				
			}
			else if($dragid == 'customer_details'){
				$order_table_obj = new SMFetchTemplate();
				$value .= $order_table_obj->fetch_customer_details($order, $template_key, 'template_details', $template_id, $active_theme_id, 'template_details');
			}
			else{
			$value .= self::$instance->drag_template_details($template_key, 'edit', 'template_details',$template_id , $active_theme_id);
			}
		}
		if($template_id ==8 || $template_id == 12 || $template_id == 13){
			$value = str_replace('{user_name}',$name,$value);
		}
		$value =str_replace('{order_no}',$orderno,$value); 
		$value =str_replace('{order_date}',$order_date,$value);
		$value = str_replace('{blog_name}',get_bloginfo(),$value);
		$value = str_replace('{user_name}',$user_login,$value);
		$value = str_replace('{customer_name}',$customer_name,$value);
		$value = str_replace('{First_name}',$name,$value);
		$value = str_replace('{Last_name}',$last_name,$value);
		$value = str_replace('{order_details}',self::$instance->ordertable_fetch($orderno,$active_theme_id),$value);
		$value = str_replace('{customer_details}',self::$instance->customer_table_fetch($orderno),$value);
		$value = str_replace('{order_name}',self::$instance->fetch_order_prod($order , 'name'),$value);
		$value = str_replace('{order_qty}',self::$instance->fetch_order_prod($order , 'product_qty'),$value);
		$value = str_replace('{product_price}',self::$instance->fetch_order_prod($order , 'total'),$value);
		$value = str_replace('{sub_total}',self::$instance->fetch_total_prod($order, 'subtotal'),$value);
		$value = str_replace('{order_total}',self::$instance->fetch_total_prod($order, 'total'),$value);
		$value = str_replace('{pay_method}',self::$instance->fetch_total_prod($order, 'pay'),$value);
		$value = str_replace('{billing_email}',$billing_email,$value);
		$value = str_replace('{billing_phone}',$billing_phone,$value);
		$value = str_replace('{billing_country}',$billing_country,$value);
		$value = str_replace('{billing_state}',$billing_state,$value);
		$value = str_replace('{billing_city}',$billing_city,$value);
		$value = str_replace('{billing_company}',$billing_company,$value);
		$value = str_replace('{billing_address_1}',$billing_address_one,$value);
		$value = str_replace('{billing_address_2}',$billing_address_two,$value);
		$value = str_replace('{billing_postcode}',$billing_postcode,$value);
		$value = str_replace('{shipping_name}',$shipping_name,$value);
		$value = str_replace('{shipping_country}',$shipping_country,$value);
		$value = str_replace('{shipping_state}',$shipping_state,$value);
		$value = str_replace('{shipping_city}',$shipping_city,$value);
		$value = str_replace('{shipping_company}',$shipping_company,$value);
		$value = str_replace('{shipping_address_1}',$shipping_address_one,$value);
		$value = str_replace('{shipping_address_2}',$shipping_address_two,$value);
		$value = str_replace('{shipping_postcode}',$shipping_postcode,$value); 
		return $value;
	}
	
}

SMTemplatePage::getInstance();

}